@@ -86,6 +86,7 @@ extern "C" {
  * arguments:
  *   rank_id        <-- id of local rank (ignored in serial mode)
  *   n_ranks        <-- number of associated ranks
+ *   min_rank_step  <-- minimum rank step between blocks
  *   min_block_size <-- minimum number of entities per block
  *   n_g_ents       <-- total number of associated entities
  *
@@ -96,6 +97,7 @@ extern "C" {
 fvm_block_dist_info_t
 fvm_block_dist_compute_sizes(int         rank_id,
                              int         n_ranks,
+                             int         min_rank_step,
                              fvm_lnum_t  min_block_size,
                              fvm_gnum_t  n_g_ents)
 {
@@ -134,6 +136,8 @@ fvm_block_dist_compute_sizes(int         rank_id,
     bi.rank_step *= 2;
     bi.n_ranks = n_ranks / bi.rank_step;
   }
+  if (bi.rank_step < min_rank_step)
+    bi.rank_step = min_rank_step;
   if (bi.rank_step > n_ranks) {
     bi.rank_step = n_ranks;
     bi.n_ranks = 1;
