@@ -332,6 +332,7 @@ _block_to_part_create(MPI_Comm comm)
  * arguments:
  *   rank_id        <-- id of local rank (ignored in serial mode)
  *   n_ranks        <-- number of associated ranks
+ *   min_rank_step  <-- minimum rank step between blocks
  *   min_block_size <-- minimum number of entities per block
  *   n_g_ents       <-- total number of associated entities
  *
@@ -342,6 +343,7 @@ _block_to_part_create(MPI_Comm comm)
 fvm_block_to_part_info_t
 fvm_block_to_part_compute_sizes(int         rank_id,
                                 int         n_ranks,
+                                int         min_rank_step,
                                 fvm_lnum_t  min_block_size,
                                 fvm_gnum_t  n_g_ents)
 {
@@ -349,6 +351,7 @@ fvm_block_to_part_compute_sizes(int         rank_id,
 
   fvm_block_dist_info_t _bi= fvm_block_dist_compute_sizes(rank_id,
                                                           n_ranks,
+                                                          min_rank_step,
                                                           min_block_size,
                                                           n_g_ents);
 
