@@ -506,13 +506,13 @@ fvm_box_set_get_g_num(fvm_box_set_t  *boxes)
 }
 
 /*----------------------------------------------------------------------------
- * Build a morton_index to get a well-balanced distribution of the boxes.
+ * Build a Morton_index to get a well-balanced distribution of the boxes.
  *
  * parameters:
  *  boxes      <-- pointer to associated fvm_box_set_t structure
  *  distrib    <-> pointer to a fvm_box_distrib_t structure
  *  n_leaves   <-- number of leaves with weight > 0
- *  leaf_codes <-- morton code for each leaf
+ *  leaf_codes <-- Morton code for each leaf
  *  weight     <-- number of boxes related to each leaf
  *---------------------------------------------------------------------------*/
 
@@ -532,14 +532,13 @@ fvm_box_set_build_morton_index(const fvm_box_set_t  *boxes,
 
   BFT_MALLOC(order, n_leaves, fvm_lnum_t);
 
-  /* Locally order morton encoding */
+  /* Locally order Morton encoding */
 
-  fvm_morton_local_order(boxes->dim,
-                         n_leaves,
+  fvm_morton_local_order(n_leaves,
                          leaf_codes,
                          order);
 
-  /* Compute a morton index on ranks and return the associated fit */
+  /* Compute a Morton index on ranks and return the associated fit */
 
   if (boxes->comm != MPI_COMM_NULL)
     distrib->fit = fvm_morton_build_rank_index(boxes->dim,
@@ -558,7 +557,7 @@ fvm_box_set_build_morton_index(const fvm_box_set_t  *boxes,
 }
 
 /*----------------------------------------------------------------------------
- * Redistribute boxes over the ranks according to the morton index to
+ * Redistribute boxes over the ranks according to the Morton index to
  * assume a better balanced distribution of the boxes.
  *
  * parameters:
