@@ -703,15 +703,16 @@ _recurse_tree_build(fvm_box_tree_t       *bt,
   int  state = 0;
   fvm_lnum_t  _next_size = 0;
 
-  int  n_ranks = 1;
-
   _Bool retval = false;
 
 #if defined(FVM_HAVE_MPI)
+
+  int  n_ranks = 1;
   MPI_Comm comm = boxes->comm;
 
   if (comm != MPI_COMM_NULL)
     MPI_Comm_size(comm, &n_ranks);
+
 #endif
 
   bt->n_build_loops += 1;
@@ -1593,8 +1594,7 @@ _build_rank_to_box_index(const fvm_box_tree_t  *bt,
 
     if (node->n_boxes > 0) {
 
-      int  id = fvm_morton_binary_search(dim,
-                                         size,
+      int  id = fvm_morton_binary_search(size,
                                          node->morton_code,
                                          search_index);
       int  rank = id_rank[id];
@@ -1651,8 +1651,7 @@ _build_rank_to_box_list(const fvm_box_tree_t  *bt,
 
     if (node->n_boxes > 0) {
 
-      int  id = fvm_morton_binary_search(dim,
-                                         size,
+      int  id = fvm_morton_binary_search(size,
                                          node->morton_code,
                                          search_index);
       int  rank = id_rank[id];
@@ -2259,11 +2258,10 @@ fvm_box_tree_get_distrib(fvm_box_tree_t        *bt,
   BFT_FREE(leaf_codes);
   BFT_FREE(weight);
 
-  /* Compact morton_index to get an array without "0 element" */
+  /* Compact Morton_index to get an array without "0 element" */
 
   for (i = 0; i < distrib->n_ranks; i++)
-    if (fvm_morton_a_gt_b(boxes->dim,
-                          distrib->morton_index[i+1],
+    if (fvm_morton_a_gt_b(distrib->morton_index[i+1],
                           distrib->morton_index[i]))
       reduce_size++;
 
@@ -2275,8 +2273,7 @@ fvm_box_tree_get_distrib(fvm_box_tree_t        *bt,
 
   for (i = 0; i < distrib->n_ranks; i++) {
 
-    if (fvm_morton_a_gt_b(boxes->dim,
-                          distrib->morton_index[i+1],
+    if (fvm_morton_a_gt_b(distrib->morton_index[i+1],
                           distrib->morton_index[i])) {
 
       reduce_index[reduce_size + 1] = distrib->morton_index[i+1];
@@ -2449,7 +2446,6 @@ fvm_box_tree_get_stats(const fvm_box_tree_t  *bt,
   fvm_box_tree_stats_t s;
 
   int dim = 3;
-  int n_ranks = 1;
 
   if (bt == NULL)
     return 0;
@@ -2504,6 +2500,7 @@ fvm_box_tree_get_stats(const fvm_box_tree_t  *bt,
 
   if (bt->comm != MPI_COMM_NULL) {
 
+    int n_ranks;
     fvm_gnum_t s_l_sum[14], s_g_sum[14];
 
     MPI_Comm_size(bt->comm, &n_ranks);
