@@ -40,7 +40,6 @@
 
 #include <bft_mem.h>
 #include <bft_printf.h>
-#include <bft_error.h>
 
 /*----------------------------------------------------------------------------
  *  Local headers
@@ -48,7 +47,6 @@
 
 #include "fvm_defs.h"
 #include "fvm_config_defs.h"
-#include "fvm_parall.h"
 
 /*----------------------------------------------------------------------------
  *  Header for the current file
