@@ -6,7 +6,7 @@
   This file is part of the "Finite Volume Mesh" library, intended to provide
   finite volume mesh and associated fields I/O and manipulation services.
 
-  Copyright (C) 2007-2008  EDF
+  Copyright (C) 2007-2009  EDF
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -101,6 +101,14 @@ struct _fvm_file_t {
  * Static global variables
  *============================================================================*/
 
+/* Default hints */
+
+#if defined(FVM_HAVE_MPI_IO)
+static fvm_file_hints_t _default_semantics = FVM_FILE_INDIVIDUAL_POINTERS;
+#else
+static fvm_file_hints_t _default_semantics = 0;
+#endif
+
 /* Convert fvm_file_seek to bft_file_seek */
 
 static bft_file_seek_t _bft_seek[3] = {BFT_FILE_SEEK_SET,
@@ -242,7 +250,7 @@ _file_read_block(fvm_file_t  *f,
     int *counts = NULL;
 
     if (f->rank == 0) {
-      if (f->n_ranks > 64)
+      if (f->n_ranks < 64)
         counts = _counts;
       else
         BFT_MALLOC(counts, f->n_ranks, int);
@@ -364,7 +372,7 @@ _file_write_block(fvm_file_t  *f,
     int *counts = NULL;
 
     if (f->rank == 0) {
-      if (f->n_ranks > 64)
+      if (f->n_ranks < 64)
         counts = _counts;
       else
         BFT_MALLOC(counts, f->n_ranks, int);
@@ -800,6 +808,7 @@ fvm_file_open(const char         *name,
 {
   int errcode = 0;
   fvm_file_t * f = NULL;
+  fvm_file_hints_t _hints = _default_semantics;
 
   BFT_MALLOC(f, 1, fvm_file_t);
 
@@ -828,6 +837,9 @@ fvm_file_open(const char         *name,
 
 #if defined(FVM_HAVE_MPI)
   {
+    if (hints != 0)
+      _hints = hints;
+
     if (comm != MPI_COMM_NULL) {
       MPI_Comm_size(comm, &(f->n_ranks));
       if (f->n_ranks > 1) {
@@ -844,14 +856,14 @@ fvm_file_open(const char         *name,
 
 #if defined(FVM_HAVE_MPI_IO)
   if (   f->comm != MPI_COMM_NULL
-      && !(hints & FVM_FILE_NO_MPI_IO)) {
+      && !(_hints & FVM_FILE_NO_MPI_IO)) {
     int positioning_mask = (  FVM_FILE_EXPLICIT_OFFSETS
                             | FVM_FILE_INDIVIDUAL_POINTERS);
-    if (hints & positioning_mask)
+    if (_hints & positioning_mask)
       f->semantics = hints & positioning_mask;
     else
       f->semantics = FVM_FILE_INDIVIDUAL_POINTERS;
-    f->semantics = f->semantics | (hints & FVM_FILE_NO_PREDISTRIBUTE);
+    f->semantics = f->semantics | (_hints & FVM_FILE_NO_PREDISTRIBUTE);
   }
 #endif
 
@@ -1574,6 +1586,56 @@ fvm_file_tell(fvm_file_t  *f)
   return retval;
 }
 
+/*----------------------------------------------------------------------------
+ * Get the default semantics for file access.
+ *
+ * returns:
+ *   current default semantics for file access
+ *----------------------------------------------------------------------------*/
+
+fvm_file_hints_t
+fvm_file_get_default_semantics(void)
+{
+  return _default_semantics;
+}
+
+/*----------------------------------------------------------------------------
+ * Set the default semantics for file access.
+ *
+ * This may fail if semantics given contain incompatible values,
+ * such as (FVM_FILE_EXPLICIT_OFFSETS | FVM_FILE_INDIVIDUAL_POINTERS),
+ * or when setting MPI-IO access semantics when MPI-IO is not available.
+ *
+ * returns:
+ *   0 if the semantics were valid, 1 otherwise.
+ *----------------------------------------------------------------------------*/
+
+int
+fvm_file_set_default_semantics(fvm_file_hints_t  hints)
+{
+  int retval = 0;
+
+  const fvm_file_hints_t mpi_io_hints = (  FVM_FILE_EXPLICIT_OFFSETS
+                                         | FVM_FILE_INDIVIDUAL_POINTERS);
+
+#if defined(FVM_HAVE_MPI_IO)
+  if (   (hints & FVM_FILE_EXPLICIT_OFFSETS)
+      && (hints & FVM_FILE_INDIVIDUAL_POINTERS))
+    retval = 1;
+  else if (   (hints & mpi_io_hints)
+           && (hints & FVM_FILE_NO_MPI_IO))
+    retval = 1;
+#else
+  if (hints & mpi_io_hints)
+    retval = 1;
+#endif
+
+  if (retval == 0)
+    _default_semantics = hints;
+
+  return retval;
+}
+
 /*----------------------------------------------------------------------------
  * Dump the metadata of a file structure in human readable form
  *
