@@ -85,7 +85,7 @@ typedef enum {
 
 /* Hints for file management */
 
-typedef int fvm_file_hints_t;
+typedef unsigned int fvm_file_hints_t;
 
 /* Offset for FVM file position indicator (int64_t in C99) */
 
@@ -395,6 +395,30 @@ fvm_file_seek(fvm_file_t       *f,
 fvm_file_off_t
 fvm_file_tell(fvm_file_t  *f);
 
+/*----------------------------------------------------------------------------
+ * Get the default semantics for file access.
+ *
+ * returns:
+ *   current default semantics for file access
+ *----------------------------------------------------------------------------*/
+
+fvm_file_hints_t
+fvm_file_get_default_semantics(void);
+
+/*----------------------------------------------------------------------------
+ * Set the default semantics for file access.
+ *
+ * This may fail if semantics given contain incompatible values,
+ * such as (FVM_FILE_EXPLICIT_OFFSETS | FVM_FILE_INDIVIDUAL_POINTERS),
+ * or when setting MPI-IO access semantics when MPI-IO is not available.
+ *
+ * returns:
+ *   0 if the semantics were valid, 1 otherwise.
+ *----------------------------------------------------------------------------*/
+
+int
+fvm_file_set_default_semantics(fvm_file_hints_t  hints);
+
 /*----------------------------------------------------------------------------
  * Dump the metadata of a file structure in human readable form
  *
