@@ -7,7 +7,7 @@
   This file is part of the "Finite Volume Mesh" library, intended to provide
   finite volume mesh and associated fields I/O and manipulation services.
 
-  Copyright (C) 2004-2007  EDF
+  Copyright (C) 2004-2009  EDF
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -630,15 +630,15 @@ fvm_gather_slice_index(const fvm_lnum_t     local_index[],
 
         if (n_distant_entities > 0) {
 
-          fvm_lnum_t *recv_buf = NULL;
+          fvm_gnum_t *recv_buf = NULL;
 
           _slice_recv_buf_size_array(this_slice, n_distant_entities,
-                                     1, sizeof(fvm_lnum_t));
+                                     1, sizeof(fvm_gnum_t));
 
           recv_buf = this_slice->recv_buf;
 
           MPI_Recv(this_slice->recv_buf, n_distant_entities,
-                   FVM_MPI_LNUM, distant_rank, FVM_MPI_TAG, comm, &status);
+                   FVM_MPI_GNUM, distant_rank, FVM_MPI_TAG, comm, &status);
 
           for (i = 0 ; i < n_distant_entities ; i++)
             slice_index[displacements[i]] = recv_buf[i];
@@ -685,7 +685,7 @@ fvm_gather_slice_index(const fvm_lnum_t     local_index[],
 
       if (n_local_entities > 0)
         MPI_Send(slice_index, (int)n_local_entities,
-                 FVM_MPI_LNUM, 0, FVM_MPI_TAG, comm);
+                 FVM_MPI_GNUM, 0, FVM_MPI_TAG, comm);
 
     }
 
