@@ -224,6 +224,9 @@ _check_morton_ordering(int                      dim,
 {
   size_t  i_prev = 0, i = 1;
 
+  if (n_entities == 0)
+    return;
+
   /* Check ordering; if two entities have the same Morton codes,
      use lexicographical coordinates ordering to ensure the
      final order is deterministic. */
@@ -415,7 +418,7 @@ _fvm_io_num_global_order(fvm_io_num_t       *this_io_num,
   for (i = 0; i < (size_t)(this_io_num->global_num_size); i++)
     send_count[(this_io_num->global_num[i] - 1) / slice_size] += 1;
 
-  MPI_Alltoall(send_count, 1, FVM_MPI_GNUM, recv_count, 1, FVM_MPI_GNUM, comm);
+  MPI_Alltoall(send_count, 1, MPI_INT, recv_count, 1, MPI_INT, comm);
 
   send_shift[0] = 0;
   recv_shift[0] = 0;
@@ -667,7 +670,7 @@ _fvm_io_num_global_order_s(fvm_io_num_t       *this_io_num,
   for (i = 0; i < (size_t)(this_io_num->global_num_size); i++)
     send_count[(global_num[stride*i] - 1) / slice_size] += stride;
 
-  MPI_Alltoall(send_count, 1, FVM_MPI_GNUM, recv_count, 1, FVM_MPI_GNUM, comm);
+  MPI_Alltoall(send_count, 1, MPI_INT, recv_count, 1, MPI_INT, comm);
 
   send_shift[0] = 0;
   recv_shift[0] = 0;
@@ -849,10 +852,12 @@ _fvm_io_num_global_order_index(fvm_io_num_t       *this_io_num,
   int  rank, local_rank, size;
   size_t  i, shift, slice_size;
 
-  fvm_gnum_t  n_ent_recv = 0, current_global_num = 0, global_num_shift = 0;
+  fvm_gnum_t  n_ent_recv = 0, n_ent_send = 0;
+  fvm_gnum_t  current_global_num = 0, global_num_shift = 0;
   int  *send_count = NULL, *recv_count = NULL;
   int  *send_shift = NULL, *recv_shift = NULL;
-  fvm_lnum_t  *recv_order = NULL,  *recv_index = NULL, *send_buffer = NULL;
+  fvm_lnum_t  *recv_order = NULL, *recv_sub_index = NULL;
+  fvm_lnum_t  *recv_sub_count = NULL, *send_sub_count = NULL;
   fvm_gnum_t  *block_global_num = NULL, *recv_global_num = NULL;
 
   /* Initialization */
@@ -912,31 +917,34 @@ _fvm_io_num_global_order_index(fvm_io_num_t       *this_io_num,
   /* Get recv_index */
 
   n_ent_recv = recv_shift[size];
-  BFT_MALLOC(recv_index, n_ent_recv + 1, fvm_lnum_t);
-  BFT_MALLOC(send_buffer, send_shift[size], fvm_lnum_t);
+  n_ent_send = send_shift[size];
 
-  assert(send_shift[size] == this_io_num->global_num_size);
+  BFT_MALLOC(recv_sub_count, n_ent_recv, fvm_lnum_t);
+  BFT_MALLOC(send_sub_count, n_ent_send, fvm_lnum_t);
+
+  assert(n_ent_send == (fvm_gnum_t)this_io_num->global_num_size);
 
   for (rank = 0; rank < size; rank++)
     send_count[rank] = 0;
 
   for (i = 0; i < (size_t)this_io_num->global_num_size; i++) {
-
     rank = (global_num[index[i]] - 1) / slice_size;
     shift = send_shift[rank] + send_count[rank];
-    send_buffer[shift] = index[i+1] - index[i];
+    send_sub_count[shift] = index[i+1] - index[i];
     send_count[rank] +=  1;
-
   }
 
-  MPI_Alltoallv(send_buffer, send_count, send_shift, FVM_MPI_LNUM,
-                &(recv_index[1]), recv_count, recv_shift, FVM_MPI_LNUM, comm);
+  MPI_Alltoallv(send_sub_count, send_count, send_shift, FVM_MPI_LNUM,
+                recv_sub_count, recv_count, recv_shift, FVM_MPI_LNUM, comm);
 
-  recv_index[0] = 0;
+  BFT_MALLOC(recv_sub_index, n_ent_recv + 1, fvm_lnum_t);
+
+  recv_sub_index[0] = 0;
   for (i = 0; i < n_ent_recv; i++)
-    recv_index[i+1] += recv_index[i];
+      recv_sub_index[i+1] = recv_sub_index[i] + recv_sub_count[i];
 
-  BFT_FREE(send_buffer);
+  BFT_FREE(send_sub_count);
+  BFT_FREE(recv_sub_count);
 
   /* Get recv_global_num */
 
@@ -960,10 +968,7 @@ _fvm_io_num_global_order_index(fvm_io_num_t       *this_io_num,
     recv_shift[rank+1] = recv_shift[rank] + recv_count[rank];
   }
 
-  assert(send_shift[size] == index[this_io_num->global_num_size]);
-  assert(recv_shift[size] == recv_index[n_ent_recv]);
-
-  BFT_MALLOC(recv_global_num, recv_index[n_ent_recv], fvm_gnum_t);
+  BFT_MALLOC(recv_global_num, recv_sub_index[n_ent_recv], fvm_gnum_t);
 
   /* As data is sorted by increasing base global numbering, we do not
      need to build an extra array, but only to send the correct parts
@@ -980,7 +985,7 @@ _fvm_io_num_global_order_index(fvm_io_num_t       *this_io_num,
 
     fvm_order_local_allocated_i(NULL,
                                 recv_global_num,
-                                recv_index,
+                                recv_sub_index,
                                 recv_order,
                                 n_ent_recv);
 
@@ -1001,7 +1006,7 @@ _fvm_io_num_global_order_index(fvm_io_num_t       *this_io_num,
 
       cur_id = recv_order[i];
 
-      if (_indexed_is_greater(cur_id, prev_id, recv_index, recv_global_num))
+      if (_indexed_is_greater(cur_id, prev_id, recv_sub_index, recv_global_num))
         current_global_num += 1;
 
       block_global_num[recv_order[i]] = current_global_num;
@@ -1014,7 +1019,7 @@ _fvm_io_num_global_order_index(fvm_io_num_t       *this_io_num,
   /* Partial clean-up */
 
   BFT_FREE(recv_order);
-  BFT_FREE(recv_index);
+  BFT_FREE(recv_sub_index);
   BFT_FREE(recv_global_num);
 
   /* At this stage, block_global_num[] is valid for this process, and
@@ -1137,7 +1142,7 @@ _fvm_io_num_global_sub_size(const fvm_io_num_t  *this_io_num,
   for (i = 0; i < (size_t)(this_io_num->global_num_size); i++)
     send_count[(this_io_num->global_num[i] - 1) / slice_size] += 1;
 
-  MPI_Alltoall(send_count, 1, FVM_MPI_GNUM, recv_count, 1, FVM_MPI_GNUM, comm);
+  MPI_Alltoall(send_count, 1, MPI_INT, recv_count, 1, MPI_INT, comm);
 
   send_shift[0] = 0;
   recv_shift[0] = 0;
@@ -1581,6 +1586,7 @@ fvm_io_num_create_from_adj_i(const fvm_lnum_t  parent_entity_number[],
       /* Assign initial global numbers */
 
       BFT_MALLOC(_index, n_entities + 1, fvm_lnum_t);
+      _index[0] = 0;
 
       if (parent_entity_number != NULL) {
 
@@ -1599,7 +1605,6 @@ fvm_io_num_create_from_adj_i(const fvm_lnum_t  parent_entity_number[],
           _index[i+1] = index[ent_id+1] - index[ent_id];
         }
 
-        _index[0] = 0;
         for (i = 0 ; i < n_entities ; i++)
           _index[i+1] += _index[i];
 
@@ -1645,8 +1650,10 @@ fvm_io_num_create_from_adj_i(const fvm_lnum_t  parent_entity_number[],
                                    _adjacency,
                                    fvm_parall_get_mpi_comm());
 
-    BFT_FREE(_adjacency);
-    BFT_FREE(_index);
+    if (_adjacency != NULL)
+      BFT_FREE(_adjacency);
+    if (_index != NULL)
+      BFT_FREE(_index);
   }
 #endif
 
@@ -1711,7 +1718,7 @@ fvm_io_num_create_from_coords(const fvm_coord_t  coords[],
 
   fvm_morton_encode_coords(dim, level, extents, n_entities, coords, m_code);
 
-  fvm_morton_local_order(dim, n_entities, m_code, order);
+  fvm_morton_local_order(n_entities, m_code, order);
 
 #if defined(FVM_HAVE_MPI)
 
@@ -1729,7 +1736,7 @@ fvm_io_num_create_from_coords(const fvm_coord_t  coords[],
     int *recv_count = NULL, *recv_shift = NULL;
     fvm_coord_t *send_coords = NULL, *recv_coords = NULL;
     fvm_lnum_t *weight = NULL;
-    fvm_gnum_t *block_global_num = NULL;
+    fvm_gnum_t *block_global_num = NULL, *part_global_num = NULL;
     fvm_morton_code_t *morton_index = NULL;
 
     BFT_MALLOC(weight, n_entities, fvm_lnum_t);
@@ -1752,8 +1759,7 @@ fvm_io_num_create_from_coords(const fvm_coord_t  coords[],
     BFT_MALLOC(c_rank, n_entities, int);
 
     for (i = 0; i < n_entities; i++)
-      c_rank[i] = fvm_morton_quantile_search(dim,
-                                             n_ranks,
+      c_rank[i] = fvm_morton_quantile_search(n_ranks,
                                              m_code[i],
                                              morton_index);
 
@@ -1800,7 +1806,6 @@ fvm_io_num_create_from_coords(const fvm_coord_t  coords[],
       send_count[rank_id] += dim;
     }
 
-    BFT_FREE(c_rank);
     BFT_MALLOC(recv_coords, recv_shift[n_ranks], fvm_coord_t);
 
     /* Exchange coords between processes */
@@ -1825,7 +1830,7 @@ fvm_io_num_create_from_coords(const fvm_coord_t  coords[],
                              recv_coords,
                              m_code);
 
-    fvm_morton_local_order(dim, n_block_ents, m_code, order);
+    fvm_morton_local_order(n_block_ents, m_code, order);
 
     /* Check ordering; if two entities have the same Morton codes,
        use lexicographical coordinates ordering to ensure the
@@ -1873,13 +1878,30 @@ fvm_io_num_create_from_coords(const fvm_coord_t  coords[],
       recv_shift[rank_id] /= dim;
     }
 
+    send_shift[n_ranks] /= dim;
+
+    BFT_MALLOC(part_global_num, send_shift[n_ranks], fvm_gnum_t);
+
     MPI_Alltoallv(block_global_num, recv_count, recv_shift, FVM_MPI_GNUM,
-                  this_io_num->_global_num, send_count, send_shift, FVM_MPI_GNUM,
+                  part_global_num, send_count, send_shift, FVM_MPI_GNUM,
                   comm);
 
+    for (rank_id = 0; rank_id < n_ranks; rank_id++)
+      send_count[rank_id] = 0;
+
+    for (i = 0; i < n_entities; i++) {
+      rank_id = c_rank[i];
+      shift = send_shift[rank_id] + send_count[rank_id];
+      this_io_num->_global_num[i] = part_global_num[shift];
+      send_count[rank_id] += 1;
+    }
+
     /* Free memory */
 
+    BFT_FREE(c_rank);
+
     BFT_FREE(block_global_num);
+    BFT_FREE(part_global_num);
 
     BFT_FREE(send_count);
     BFT_FREE(recv_count);
@@ -1900,7 +1922,7 @@ fvm_io_num_create_from_coords(const fvm_coord_t  coords[],
 
     BFT_FREE(m_code);
 
-    for (i = 1; i < n_entities; i++)
+    for (i = 0; i < n_entities; i++)
       this_io_num->_global_num[order[i]] = i+1;
 
     BFT_FREE(order);
@@ -1912,6 +1934,63 @@ fvm_io_num_create_from_coords(const fvm_coord_t  coords[],
   return this_io_num;
 }
 
+/*----------------------------------------------------------------------------
+ * Creation of an I/O numbering structure based on a simple accumulation
+ * (i.e. scan) of counts on successive ranks.
+ *
+ * parameters:
+ *   n_entities <-- number of entities considered
+ *
+ * returns:
+ *  pointer to I/O numbering structure
+ *----------------------------------------------------------------------------*/
+
+fvm_io_num_t *
+fvm_io_num_create_from_scan(size_t  n_entities)
+{
+  fvm_io_num_t  *this_io_num = NULL;
+
+  /* Initial checks */
+
+  if (fvm_parall_get_size() < 2)
+    return NULL;
+
+#if defined(FVM_HAVE_MPI)
+  {
+    size_t  i;
+    fvm_gnum_t gnum_base = n_entities;
+    fvm_gnum_t gnum_sum = n_entities;
+    fvm_gnum_t gnum_shift = 0;
+
+    MPI_Comm comm = fvm_parall_get_mpi_comm();
+
+    /* Create structure */
+
+    BFT_MALLOC(this_io_num, 1, fvm_io_num_t);
+
+    BFT_MALLOC(this_io_num->_global_num, n_entities, fvm_gnum_t);
+    this_io_num->global_num = this_io_num->_global_num;
+
+    this_io_num->global_num_size = n_entities;
+
+    MPI_Scan(&gnum_base, &gnum_shift, 1, FVM_MPI_GNUM, MPI_SUM, comm);
+
+    gnum_base = gnum_shift - gnum_base + 1;
+
+    for (i = 0; i < n_entities; i++)
+      this_io_num->_global_num[i] = gnum_base + i;
+
+    gnum_base = n_entities;
+
+    MPI_Allreduce(&gnum_base, &gnum_sum, 1, FVM_MPI_GNUM, MPI_SUM, comm);
+
+    this_io_num->global_count = gnum_sum;
+  }
+#endif
+
+  return this_io_num;
+}
+
 /*----------------------------------------------------------------------------
  * Destruction of a I/O numbering structure.
  *
