@@ -356,7 +356,7 @@ _elt_extents_finalize(int               dim,
     delta[i] = (elt_extents[i+dim] - elt_extents[i]) * tolerance;
 
   if (elt_dim < dim) {
-    double delta_max = delta[0];    /* for 1d or 2d elements, ensure */
+    double delta_max = delta[0];  /* for 1d or 2d elements, ensure */
     for (i = 0; i < dim; i++) {   /* search extent "thickness" */
       if (delta[i] > delta_max)
         delta_max = delta[i];
@@ -2288,14 +2288,14 @@ fvm_locator_dump(const fvm_locator_t  *this_locator)
   /* Basic information */
   /*-------------------*/
 
-  bft_printf(_("\n"
-               "Locator:\n\n"
-               "Tolerance:                             %f\n"
-               "Locate on parents:                     %d\n"
-               "Spatial dimension:                     %d\n"
-               "Number of ranks of distant location:   %d\n"
-               "First rank of distant location:        %d\n"
-               "Number of intersecting distant ranks:  %d\n"),
+  bft_printf("\n"
+             "Locator:\n\n"
+             "Tolerance:                             %f\n"
+             "Locate on parents:                     %d\n"
+             "Spatial dimension:                     %d\n"
+             "Number of ranks of distant location:   %d\n"
+             "First rank of distant location:        %d\n"
+             "Number of intersecting distant ranks:  %d\n",
              _locator->tolerance,
              (int)_locator->locate_on_parents, _locator->dim,
              _locator->n_ranks, _locator->start_rank,
@@ -2303,8 +2303,8 @@ fvm_locator_dump(const fvm_locator_t  *this_locator)
 
 #if defined(FVM_HAVE_MPI)
   if (_locator->comm != MPI_COMM_NULL)
-    bft_printf(_("\n"
-                 "Associated MPI communicator:           %ld\n"),
+    bft_printf("\n"
+               "Associated MPI communicator:           %ld\n",
                (long)(_locator->comm));
 #endif
 
@@ -2313,15 +2313,15 @@ fvm_locator_dump(const fvm_locator_t  *this_locator)
 
   for (i = 0; i < _locator->n_intersects; i++) {
 
-    bft_printf(_("\n"
-                 "  Intersection %d with distant rank %d\n\n"),
+    bft_printf("\n"
+               "  Intersection %d with distant rank %d\n\n",
                i+1, _locator->intersect_rank[i]);
 
-    bft_printf(_("    Distant rank extents:\n"));
+    bft_printf("    Distant rank extents:\n");
 
     k = i * (_locator->dim) * 2;
     for (j = 0; j < _locator->dim; j++)
-      bft_printf(_("    [%12.5e, %12.5e]\n"),
+      bft_printf("    [%12.5e, %12.5e]\n",
                  _locator->intersect_extents[k + j],
                  _locator->intersect_extents[k + _locator->dim + j]);
 
@@ -2331,7 +2331,7 @@ fvm_locator_dump(const fvm_locator_t  *this_locator)
 
     if (_locator->local_point_ids != NULL) {
 
-      bft_printf(_("\n  Local point ids (for receiving):\n\n"));
+      bft_printf("\n  Local point ids (for receiving):\n\n");
       idx = _locator->local_points_idx;
       index = _locator->local_point_ids;
       for (i = 0; i < _locator->n_intersects; i++) {
@@ -2344,7 +2344,7 @@ fvm_locator_dump(const fvm_locator_t  *this_locator)
         else {
           bft_printf("%6d (idx = %10d)\n", i + 1, idx[i]);
         }
-        bft_printf(_("   end (idx = %10d)\n"), idx[_locator->n_intersects]);
+        bft_printf("   end (idx = %10d)\n", idx[_locator->n_intersects]);
       }
 
     }
@@ -2358,7 +2358,7 @@ fvm_locator_dump(const fvm_locator_t  *this_locator)
     coords = _locator->distant_point_coords;
 
     if (idx[_locator->n_intersects] > 0)
-      bft_printf(_("\n  Distant point location:\n\n"));
+      bft_printf("\n  Distant point location:\n\n");
 
     for (i = 0; i < _locator->n_intersects; i++) {
 
@@ -2395,14 +2395,14 @@ fvm_locator_dump(const fvm_locator_t  *this_locator)
     }
 
     if (idx[_locator->n_intersects] > 0)
-      bft_printf(_("   end (idx = %10d)\n"), idx[_locator->n_intersects]);
+      bft_printf("   end (idx = %10d)\n", idx[_locator->n_intersects]);
   }
 
   /* Local arrays */
   /*--------------*/
 
-  bft_printf(_("\n"
-               "  Number of local points successfully located:  %d\n\n"),
+  bft_printf("\n"
+             "  Number of local points successfully located:  %d\n\n",
              _locator->n_interior);
 
   for (j = 0; j < _locator->n_interior; j++)
@@ -2411,7 +2411,7 @@ fvm_locator_dump(const fvm_locator_t  *this_locator)
   if  (_locator->n_interior > 0)
     bft_printf("\n");
 
-  bft_printf(_("  Number of local points not located:  %d\n"),
+  bft_printf("  Number of local points not located:  %d\n",
              _locator->n_exterior);
 
   for (j = 0; j < _locator->n_exterior; j++)
@@ -2423,16 +2423,16 @@ fvm_locator_dump(const fvm_locator_t  *this_locator)
   /* Timing information */
   /*--------------------*/
 
-  bft_printf(_("  Location Wall-clock time: %12.5f (comm: %12.5f)\n"),
+  bft_printf("  Location Wall-clock time: %12.5f (comm: %12.5f)\n",
              _locator->location_wtime[0], _locator->location_wtime[0]);
 
-  bft_printf(_("  Location CPU time:        %12.5f (comm: %12.5f)\n"),
+  bft_printf("  Location CPU time:        %12.5f (comm: %12.5f)\n",
              _locator->location_cpu_time[0], _locator->location_cpu_time[0]);
 
-  bft_printf(_("  Exchange Wall-clock time: %12.5f (comm: %12.5f)\n"),
+  bft_printf("  Exchange Wall-clock time: %12.5f (comm: %12.5f)\n",
              _locator->exchange_wtime[0], _locator->exchange_wtime[0]);
 
-  bft_printf(_("  Exchange CPU time:        %12.5f (comm: %12.5f)\n"),
+  bft_printf("  Exchange CPU time:        %12.5f (comm: %12.5f)\n",
              _locator->exchange_cpu_time[0], _locator->exchange_cpu_time[0]);
 
 }
