@@ -137,7 +137,6 @@ _local_to_global_extents(int          dim,
  * Test if Morton code "a" is greater or equal to Morton code "b"
  *
  * parameters:
- *   dim    <-- 2D or 3D.
  *   code_a <-- first Morton code to compare
  *   code_b <-- second Morton code to compare
  *
@@ -146,72 +145,52 @@ _local_to_global_extents(int          dim,
  *----------------------------------------------------------------------------*/
 
 inline static _Bool
-_a_ge_b(int                dim,
-        fvm_morton_code_t  code_a,
+_a_ge_b(fvm_morton_code_t  code_a,
         fvm_morton_code_t  code_b)
 {
-  int i;
+  int i, a, b, a_diff, b_diff;
+  int l = FVM_MAX(code_a.L, code_b.L);
 
-  if (code_a.L == code_b.L) {
-
-    for (i = 0; i < dim; i++) {
-      if (code_a.X[i] > code_b.X[i])
-        return true;
-      else if (code_a.X[i] < code_b.X[i])
-        return false;
-    }
-
-    return true; /* Equal */
+  a_diff = l - code_a.L;
+  b_diff = l - code_b.L;
 
+  if (a_diff > 0) {
+    code_a.L = l;
+    code_a.X[0] = code_a.X[0] << a_diff;
+    code_a.X[1] = code_a.X[2] << a_diff;
+    code_a.X[1] = code_a.X[2] << a_diff;
   }
-  else {
 
-    if (code_a.L < code_b.L) {
+  if (b_diff > 0) {
+    code_b.L = l;
+    code_b.X[0] = code_b.X[0] << b_diff;
+    code_b.X[1] = code_b.X[2] << b_diff;
+    code_b.X[1] = code_b.X[2] << b_diff;
+  }
 
-      fvm_morton_int_t  delta = code_b.L - code_a.L;
+  i = l - 1;
+  while (i > 0) {
+    if (   code_a.X[0] >> i != code_b.X[0] >> i
+        || code_a.X[1] >> i != code_b.X[1] >> i
+        || code_a.X[2] >> i != code_b.X[2] >> i)
+      break;
+    i--;
+  }
 
-      for (i = 0; i < dim; i++) {
+  a =   ((code_a.X[0] >> i) % 2) * 4
+      + ((code_a.X[1] >> i) % 2) * 2
+      + ((code_a.X[2] >> i) % 2);
+  b =   ((code_b.X[0] >> i) % 2) * 4
+      + ((code_b.X[1] >> i) % 2) * 2
+      + ((code_b.X[2] >> i) % 2);
 
-        code_a.X[i] = code_a.X[i] << delta;
-        if (code_a.X[i] > code_b.X[i])
-          return true;
-        else if (code_a.X[i] < code_b.X[i])
-          return false;
-
-      }
-
-      return false; /* Same anchor but code_a.L < code_b.L */
-    }
-    else { /* code_a.L > code_b.L */
-
-      fvm_morton_int_t  delta = code_a.L - code_b.L;
-
-      for (i = 0; i < dim; i++) {
-
-        code_b.X[i] = code_b.X[i] << delta;
-        if (code_a.X[i] > code_b.X[i])
-          return true;
-        else if (code_a.X[i] < code_b.X[i])
-          return false;
-
-      }
-
-      return true; /* Same anchor but code_a.L > code_b.L */
-    }
-
-  } /* code_a.L != code_b.L */
-
-  /* Never reach this point. To avoid a warning during compilation */
-  assert(0);
-
-  return true;
+  return (a >= b) ? true : false;
 }
 
 /*----------------------------------------------------------------------------
  * Test if Morton code "a" is greater than Morton code "b"
  *
  * parameters:
- *   dim    <-- 2D or 3D.
  *   code_a <-- first Morton code to compare
  *   code_b <-- second Morton code to compare
  *
@@ -220,76 +199,59 @@ _a_ge_b(int                dim,
  *----------------------------------------------------------------------------*/
 
 inline static _Bool
-_a_gt_b(int                dim,
-        fvm_morton_code_t  code_a,
+_a_gt_b(fvm_morton_code_t  code_a,
         fvm_morton_code_t  code_b)
 {
-  int i;
+  int i, a, b, a_diff, b_diff;
+  int l = FVM_MAX(code_a.L, code_b.L);
 
-  if (code_a.L == code_b.L) {
-
-    for (i = 0; i < dim; i++) {
-      if (code_a.X[i] > code_b.X[i])
-        return true;
-      else if (code_a.X[i] < code_b.X[i])
-        return false;
-    }
-
-    return false; /* Equal but not greater than */
+  a_diff = l - code_a.L;
+  b_diff = l - code_b.L;
 
+  if (a_diff > 0) {
+    code_a.L = l;
+    code_a.X[0] = code_a.X[0] << a_diff;
+    code_a.X[1] = code_a.X[2] << a_diff;
+    code_a.X[1] = code_a.X[2] << a_diff;
   }
-  else {
 
-    if (code_a.L < code_b.L) {
+  if (b_diff > 0) {
+    code_b.L = l;
+    code_b.X[0] = code_b.X[0] << b_diff;
+    code_b.X[1] = code_b.X[2] << b_diff;
+    code_b.X[1] = code_b.X[2] << b_diff;
+  }
 
-      fvm_morton_int_t  delta = code_b.L - code_a.L;
+  i = l - 1;
+  while (i > 0) {
+    if (   code_a.X[0] >> i != code_b.X[0] >> i
+        || code_a.X[1] >> i != code_b.X[1] >> i
+        || code_a.X[2] >> i != code_b.X[2] >> i)
+      break;
+    i--;
+  }
 
-      for (i = 0; i < dim; i++) {
-
-        code_a.X[i] = code_a.X[i] << delta;
-        if (code_a.X[i] > code_b.X[i])
-          return true;
-        else if (code_a.X[i] < code_b.X[i])
-          return false;
-
-      }
-
-      return false; /* Same anchor but code_a.L < code_b.L */
-    }
-    else { /* code_a.L > code_b.L */
-
-      fvm_morton_int_t  delta = code_a.L - code_b.L;
-
-      for (i = 0; i < dim; i++) {
-
-        code_b.X[i] = code_b.X[i] << delta;
-        if (code_a.X[i] > code_b.X[i])
-          return true;
-        else if (code_a.X[i] < code_b.X[i])
-          return false;
-
-      }
-
-      return true; /* Same anchor but code_a.L > code_b.L */
-    }
-
-  } /* code_a.L != code_b.L */
+  a =   ((code_a.X[0] >> i) % 2) * 4
+      + ((code_a.X[1] >> i) % 2) * 2
+      + ((code_a.X[2] >> i) % 2);
+  b =   ((code_b.X[0] >> i) % 2) * 4
+      + ((code_b.X[1] >> i) % 2) * 2
+      + ((code_b.X[2] >> i) % 2);
 
+  return (a > b) ? true : false;
 }
 
 /*----------------------------------------------------------------------------
  * Build a heap structure or order a heap structure.
  *
  * parameters:
- *  dim          <--  2D or 3D
  *  parent       <--  parent id in the Morton code list
  *  n_codes      <--  number of codes to work with
  *  morton_codes <->  list of Morton codes to work with
  *----------------------------------------------------------------------------*/
 
 static void
-_descend_morton_heap(int                dim,
-                     fvm_gnum_t         parent,
+_descend_morton_heap(fvm_gnum_t         parent,
                      fvm_lnum_t         n_codes,
                      fvm_morton_code_t  morton_codes[])
 {
@@ -299,10 +261,10 @@ _descend_morton_heap(int                dim,
   while (child < n_codes) {
 
     if (child + 1 < n_codes)
-      if (_a_gt_b(dim, morton_codes[child + 1], morton_codes[child]))
+      if (_a_gt_b(morton_codes[child + 1], morton_codes[child]))
         child++;
 
-    if (_a_ge_b(dim, morton_codes[parent], morton_codes[child])) return;
+    if (_a_ge_b(morton_codes[parent], morton_codes[child])) return;
 
     tmp = morton_codes[parent];
     morton_codes[parent] = morton_codes[child];
@@ -361,7 +323,6 @@ _double_to_code(int     dim,
  * to save the ordering.
  *
  * parameters:
- *  dim          <-- 2D or 3D
  *  parent       <-- parent id in the Morton code list
  *  n_codes      <-- number of codes to work with
  *  morton_codes <-- list of Morton codes to work with
@@ -369,8 +330,7 @@ _double_to_code(int     dim,
  *----------------------------------------------------------------------------*/
 
 static void
-_descend_morton_heap_with_order(int                       dim,
-                                fvm_gnum_t                parent,
+_descend_morton_heap_with_order(fvm_gnum_t                parent,
                                 fvm_lnum_t                n_codes,
                                 const fvm_morton_code_t   morton_codes[],
                                 fvm_lnum_t               *order)
@@ -381,14 +341,12 @@ _descend_morton_heap_with_order(int                       dim,
   while (child < n_codes) {
 
     if (child + 1 < n_codes) {
-      if (_a_gt_b(dim,
-                  morton_codes[order[child + 1]],
+      if (_a_gt_b(morton_codes[order[child + 1]],
                   morton_codes[order[child]]))
         child++;
     }
 
-    if (_a_ge_b(dim,
-                morton_codes[order[parent]],
+    if (_a_ge_b(morton_codes[order[parent]],
                 morton_codes[order[child]]))
       return;
 
@@ -401,6 +359,8 @@ _descend_morton_heap_with_order(int                       dim,
   } /* End while */
 }
 
+#if defined(FVM_HAVE_MPI)
+
 /*----------------------------------------------------------------------------
  * Evaluate a distribution array.
  *
@@ -450,8 +410,6 @@ _evaluate_distribution(int          n_ranges,
   return  fit;
 }
 
-#if defined(FVM_HAVE_MPI)
-
 /*----------------------------------------------------------------------------
  * Define a global distribution associated to a sampling array i.e. count
  * the number of elements in each range.
@@ -512,12 +470,12 @@ _define_rank_distrib(int                      dim,
 
     fvm_gnum_t  o_id = order[i];
 
-    if (_a_ge_b(dim, sample_code, morton_codes[o_id]))
+    if (_a_ge_b(sample_code, morton_codes[o_id]))
       l_distrib[bucket_id - 1] += weight[o_id];
 
     else {
 
-      while (_a_gt_b(dim, morton_codes[o_id], sample_code)) {
+      while (_a_gt_b(morton_codes[o_id], sample_code)) {
 
         bucket_id++;
         assert(bucket_id < n_samples + 1);
@@ -1007,12 +965,19 @@ fvm_morton_encode_coords(int                dim,
 {
   size_t i, j;
   fvm_coord_t s[3], d[3], n[3];
+  fvm_coord_t d_max = 0.0;
 
   fvm_morton_int_t  refinement = 1 << level;
 
   for (i = 0; i < (size_t)dim; i++) {
     s[i] = extents[i];
     d[i] = extents[i+dim] - extents[i];
+    d_max = FVM_MAX(d_max, d[i]);
+  }
+
+  for (i = 0; i < (size_t)dim; i++) { /* Reduce effective dimension */
+    if (d[i] < d_max * 1e-10)
+      d[i] = d_max * 1e-10;
   }
 
   switch(dim) {
@@ -1118,15 +1083,13 @@ fvm_morton_get_children(int                dim,
  * Locally order a list of Morton ids.
  *
  * parameters:
- *   dim          <-- 1D, 2D or 3D
  *   n_codes      <-- number of Morton ids to order
  *   morton_codes <-- array of Morton ids to order
  *   order        --> pointer to pre-allocated ordering table
  *----------------------------------------------------------------------------*/
 
 void
-fvm_morton_local_order(int                      dim,
-                       fvm_lnum_t               n_codes,
+fvm_morton_local_order(fvm_lnum_t               n_codes,
                        const fvm_morton_code_t  morton_codes[],
                        fvm_lnum_t               order[])
 {
@@ -1142,7 +1105,7 @@ fvm_morton_local_order(int                      dim,
   /* Build heap */
 
   for (i = n_codes/2 - 1; (int)i >= 0; i--)
-    _descend_morton_heap_with_order(dim, i,  n_codes, morton_codes, order);
+    _descend_morton_heap_with_order(i,  n_codes, morton_codes, order);
 
   /* Sort array */
 
@@ -1152,13 +1115,13 @@ fvm_morton_local_order(int                      dim,
     order[0] = order[i];
     order[i] = tmp;
 
-    _descend_morton_heap_with_order(dim, 0, i, morton_codes, order);
+    _descend_morton_heap_with_order(0, i, morton_codes, order);
 
   }
 
 #if 0 && defined(DEBUG) && !defined(NDEBUG)   /* Check ordering */
   for (i = 1; i < n_codes; i++) {
-    if (_a_gt_b(dim, morton_codes[order[i-1]], morton_codes[order[i]]))
+    if (_a_gt_b(morton_codes[order[i-1]], morton_codes[order[i]]))
       bft_error(__FILE__, __LINE__, 0,
                 "Id: %u inconsistent: bad ordering of Morton codes.",
                 (unsigned)i);
@@ -1170,14 +1133,12 @@ fvm_morton_local_order(int                      dim,
  * Locally sort a list of Morton ids.
  *
  * parameters:
- *   dim          <-- 1D, 2D or 3D
  *   n_codes      <-- number of Morton ids to order
  *   morton_codes <-> array of Morton ids to sort
  *----------------------------------------------------------------------------*/
 
 void
-fvm_morton_local_sort(int                dim,
-                      fvm_lnum_t         n_codes,
+fvm_morton_local_sort(fvm_lnum_t         n_codes,
                       fvm_morton_code_t  morton_codes[])
 {
   fvm_lnum_t  i;
@@ -1186,7 +1147,7 @@ fvm_morton_local_sort(int                dim,
   /* Build heap */
 
   for (i = n_codes/2 - 1; (int)i >= 0; i--)
-    _descend_morton_heap(dim, i, n_codes, morton_codes);
+    _descend_morton_heap(i, n_codes, morton_codes);
 
   /* Sort array */
 
@@ -1196,7 +1157,7 @@ fvm_morton_local_sort(int                dim,
     morton_codes[0] = morton_codes[i];
     morton_codes[i] = tmp;
 
-    _descend_morton_heap(dim, 0, i, morton_codes);
+    _descend_morton_heap(0, i, morton_codes);
 
   }
 
@@ -1271,7 +1232,6 @@ fvm_morton_compare(int                dim,
  * Test if Morton code "a" is greater than Morton code "b"
  *
  * parameters:
- *   dim    <-- 2D or 3D
  *   code_a <-- first Morton code to compare
  *   code_b <-- second Morton code to compare
  *
@@ -1280,18 +1240,16 @@ fvm_morton_compare(int                dim,
  *----------------------------------------------------------------------------*/
 
 _Bool
-fvm_morton_a_gt_b(int                dim,
-                  fvm_morton_code_t  a,
+fvm_morton_a_gt_b(fvm_morton_code_t  a,
                   fvm_morton_code_t  b)
 {
-  return  _a_gt_b(dim, a, b);
+  return  _a_gt_b(a, b);
 }
 
 /*----------------------------------------------------------------------------
  * Test if Morton code "a" is greater or equal to Morton code "b"
  *
  * parameters:
- *   dim    <-- 1D, 2D or 3D
  *   code_a <-- first Morton code to compare
  *   code_b <-- second Morton code to compare
  *
@@ -1300,11 +1258,10 @@ fvm_morton_a_gt_b(int                dim,
  *----------------------------------------------------------------------------*/
 
 _Bool
-fvm_morton_a_ge_b(int                dim,
-                  fvm_morton_code_t  a,
+fvm_morton_a_ge_b(fvm_morton_code_t  a,
                   fvm_morton_code_t  b)
 {
-  return  _a_ge_b(dim, a, b);
+  return  _a_ge_b(a, b);
 }
 
 /*----------------------------------------------------------------------------
@@ -1313,7 +1270,6 @@ fvm_morton_a_ge_b(int                dim,
  * No check is done to ensure that the code is present in the array.
  *
  * parameters:
- *   dim   <-- 1D, 2D or 3D
  *   size  <-- size of the array
  *   code  <-- code we are searching for
  *   codes <-- array of Morton codes
@@ -1323,8 +1279,7 @@ fvm_morton_a_ge_b(int                dim,
  *----------------------------------------------------------------------------*/
 
 int
-fvm_morton_binary_search(int                 dim,
-                         fvm_lnum_t          size,
+fvm_morton_binary_search(fvm_lnum_t          size,
                          fvm_morton_code_t   code,
                          fvm_morton_code_t  *codes)
 {
@@ -1335,7 +1290,7 @@ fvm_morton_binary_search(int                 dim,
 
     int  middle = (end - start)/2 + start;
 
-    if (_a_gt_b(dim, codes[middle], code))
+    if (_a_gt_b(codes[middle], code))
       end = middle;
     else
       start = middle;
@@ -1350,7 +1305,6 @@ fvm_morton_binary_search(int                 dim,
  * No check is done to ensure that the code is present in the quantiles.
  *
  * parameters:
- *   dim            <-- 1D, 2D or 3D
  *   n_quantiles    <-- number of quantiles
  *   code           <-- code we are searching for
  *   quantile_start <-- first Morton code in each quantile (size: n_quantiles)
@@ -1360,8 +1314,7 @@ fvm_morton_binary_search(int                 dim,
  *----------------------------------------------------------------------------*/
 
 size_t
-fvm_morton_quantile_search(int                 dim,
-                           size_t              n_quantiles,
+fvm_morton_quantile_search(size_t              n_quantiles,
                            fvm_morton_code_t   code,
                            fvm_morton_code_t  *quantile_start)
 {
@@ -1373,7 +1326,7 @@ fvm_morton_quantile_search(int                 dim,
 
   while (start_id + 1 < end_id) {
     mid_id = start_id + ((end_id -start_id) / 2);
-    if (_a_gt_b(dim, quantile_start[mid_id], code))
+    if (_a_gt_b(quantile_start[mid_id], code))
       end_id = mid_id;
     else
       start_id = mid_id;
@@ -1385,7 +1338,7 @@ fvm_morton_quantile_search(int                 dim,
      find the find highest one */
 
   while (   start_id < n_quantiles - 1
-         && _a_ge_b(dim, code, quantile_start[start_id+1]))
+         && _a_ge_b(code, quantile_start[start_id+1]))
     start_id++;
 
   return start_id;
@@ -1399,14 +1352,14 @@ fvm_morton_quantile_search(int                 dim,
  * The rank_index[i] contains the first Morton code assigned to rank [i].
  *
  * parameters:
- *   dims        <--  2D or 3D
- *   gmax_level  <--  level in octree used to build the Morton encoding
- *   n_codes     <--  number of Morton codes to be indexed
- *   morton_code <--  array of Morton codes to be indexed
- *   weight      <--  weighting related to each code
- *   order       <--  ordering array
- *   rank_index  <->  pointer to the global Morton encoding rank index
- *   comm        <--  MPI communicator on which we build the global index
+ *   dim         <-- 1D, 2D or 3D
+ *   gmax_level  <-- level in octree used to build the Morton encoding
+ *   n_codes     <-- number of Morton codes to be indexed
+ *   morton_code <-- array of Morton codes to be indexed
+ *   weight      <-- weighting related to each code
+ *   order       <-- ordering array
+ *   rank_index  <-> pointer to the global Morton encoding rank index
+ *   comm        <-- MPI communicator on which we build the global index
  *
  * returns:
  *  the fit related to the Morton encoding distribution (lower is better).
@@ -1429,8 +1382,6 @@ fvm_morton_build_rank_index(int                      dim,
 
   const int  sampling_factor = _sampling_factors[dim];
 
-  assert(sizeof(fvm_gnum_t) == sizeof(fvm_lnum_t));
-
   /* Allocations and Initialization */
 
   MPI_Comm_size(comm, &n_ranks);
