@@ -375,7 +375,7 @@ _clean_neighbor_nums(fvm_neighborhood_t  *n)
   n_elts = n->n_elts;
   n_neighbors = n->neighbor_index[n_elts];
 
-  /* Remove elements with no neighbors as well as redundant elements */
+  /* Remove redundant elements */
 
   saved_id = n->neighbor_index[0];
 
@@ -395,11 +395,11 @@ _clean_neighbor_nums(fvm_neighborhood_t  *n)
           n->neighbor_num[n_count++] = n->neighbor_num[j];
       }
 
-      saved_id = end_id;
-      n->neighbor_index[i+1] = n_count;
-
     }
 
+    saved_id = end_id;
+    n->neighbor_index[i+1] = n_count;
+
   } /* End of loop on elements */
 
   if (n_count < n_neighbors)
@@ -531,6 +531,7 @@ _sync_by_block(fvm_neighborhood_t  *n,
   fvm_part_to_block_info_t bi = fvm_part_to_block_compute_sizes(rank_id,
                                                                 n_ranks,
                                                                 0,
+                                                                0,
                                                                 n_g_elts);
 
   /* Allocate buffers */
@@ -1024,9 +1025,8 @@ fvm_neighborhood_by_boxes(fvm_neighborhood_t  *n,
                               &(n->neighbor_num));
 
 #if 0 && defined(DEBUG) && !defined(NDEBUG)
-    fvm_box_tree_dump(bt);
-    fvm_box_set_dump(boxes, 1);
-  }
+  fvm_box_tree_dump(bt);
+  fvm_box_set_dump(boxes, 1);
 #endif
 
   /* Destroy the associated box tree */
