@@ -6,7 +6,7 @@
   This file is part of the "Finite Volume Mesh" library, intended to provide
   finite volume mesh and associated fields I/O and manipulation services.
 
-  Copyright (C) 2004-2008  EDF
+  Copyright (C) 2004-2009  EDF
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -81,10 +81,53 @@ const int  fvm_nodal_n_vertices_element[] = {2,   /* Edge */
                                              8,   /* Hexahedron */
                                              0};  /* Simple polyhedron */
 
+/* Number of vertices associated with each "nodal" element type */
+
+static int  fvm_nodal_n_edges_element[] = {1,   /* Edge */
+                                           3,   /* Triangle */
+                                           4,   /* Quadrangle */
+                                           0,   /* Simple polygon */
+                                           6,   /* Tetrahedron */
+                                           8,   /* Pyramid */
+                                           9,   /* Prism */
+                                           12,  /* Hexahedron */
+                                           0};  /* Simple polyhedron */
+
 /*============================================================================
  * Private function definitions
  *============================================================================*/
 
+/*----------------------------------------------------------------------------
+ * Compare edges (qsort function).
+ *
+ * parameters:
+ *   x <-> pointer to first edge definition
+ *   y <-> pointer to second edge definition
+ *
+ * returns:
+ *   result of strcmp() on group names
+ *----------------------------------------------------------------------------*/
+
+static int _compare_edges(const void *x, const void *y)
+{
+  int retval = 1;
+
+  const fvm_lnum_t *e0 = x;
+  const fvm_lnum_t *e1 = y;
+
+  if (e0[0] < e1[0])
+    retval = -1;
+
+  else if (e0[0] == e1[0]) {
+    if (e0[1] < e1[1])
+      retval = -1;
+    else if (e0[1] == e1[1])
+      retval = 0;
+  }
+
+  return retval;
+}
+
 /*----------------------------------------------------------------------------
  * Copy a nodal mesh section representation structure, sharing arrays
  * with the original structure.
@@ -447,45 +490,45 @@ _fvm_nodal_section_dump(const fvm_nodal_section_t  *this_section)
   /* Global indicators */
   /*--------------------*/
 
-  bft_printf(_("\n"
-               "Entity dimension:     %d\n"
-               "Number of elements:   %ld\n"
-               "Element type:         %s\n"),
+  bft_printf("\n"
+             "Entity dimension:     %d\n"
+             "Number of elements:   %ld\n"
+             "Element type:         %s\n",
              this_section->entity_dim, (long)this_section->n_elements,
              fvm_elements_type_name[this_section->type]);
 
-  bft_printf(_("\n"
-               "Connectivity_size:     %lu\n"
-               "Stride:                %d\n"
-               "Number of faces:       %d\n"),
+  bft_printf("\n"
+             "Connectivity_size:     %lu\n"
+             "Stride:                %d\n"
+             "Number of faces:       %d\n",
              (unsigned long)(this_section->connectivity_size),
              this_section->stride,
              (long)(this_section->n_faces));
 
-  bft_printf(_("\n"
-               "Pointers to shareable arrays:\n"
-               "  face_index:           %p\n"
-               "  face_num:             %p\n"
-               "  vertex_index:         %p\n"
-               "  vertex_num:           %p\n"
-               "  parent_element_num:   %p\n"),
+  bft_printf("\n"
+             "Pointers to shareable arrays:\n"
+             "  face_index:           %p\n"
+             "  face_num:             %p\n"
+             "  vertex_index:         %p\n"
+             "  vertex_num:           %p\n"
+             "  parent_element_num:   %p\n",
              this_section->face_index, this_section->face_num,
              this_section->vertex_index, this_section->vertex_num,
              this_section->parent_element_num);
 
-  bft_printf(_("\n"
-               "Pointers to local arrays:\n"
-               "  _face_index:          %p\n"
-               "  _face_num:            %p\n"
-               "  _vertex_index:        %p\n"
-               "  _vertex_num:          %p\n"
-               "  _parent_element_num:  %p\n"),
+  bft_printf("\n"
+             "Pointers to local arrays:\n"
+             "  _face_index:          %p\n"
+             "  _face_num:            %p\n"
+             "  _vertex_index:        %p\n"
+             "  _vertex_num:          %p\n"
+             "  _parent_element_num:  %p\n",
              this_section->_face_index, this_section->_face_num,
              this_section->_vertex_index, this_section->_vertex_num,
              this_section->_parent_element_num);
 
   if (this_section->face_index != NULL) {
-    bft_printf(_("\nPolyhedra -> faces (polygons) connectivity:\n\n"));
+    bft_printf("\nPolyhedra -> faces (polygons) connectivity:\n\n");
     n_elements = this_section->n_elements;
     idx = this_section->face_index;
     num = this_section->face_num;
@@ -495,13 +538,13 @@ _fvm_nodal_section_dump(const fvm_nodal_section_t  *this_section)
       for (j = idx[i] + 1; j < idx[i + 1]; j++)
         bft_printf("                              %10d\n", num[j]);
     }
-    bft_printf(_("      end  (idx = %10d)\n"), idx[n_elements]);
+    bft_printf("      end  (idx = %10d)\n", idx[n_elements]);
   }
 
   if (this_section->vertex_index != NULL) {
     fvm_lnum_t  n_faces = (this_section->n_faces > 0) ?
                           this_section->n_faces : this_section->n_elements;
-    bft_printf(_("\nPolygons -> vertices connectivity:\n\n"));
+    bft_printf("\nPolygons -> vertices connectivity:\n\n");
     idx = this_section->vertex_index;
     num = this_section->vertex_num;
     for (i = 0; i < n_faces; i++) {
@@ -510,11 +553,11 @@ _fvm_nodal_section_dump(const fvm_nodal_section_t  *this_section)
       for (j = idx[i] + 1; j < idx[i + 1]; j++)
         bft_printf("                              %10d\n", num[j]);
     }
-    bft_printf(_("      end  (idx = %10d)\n"), idx[n_faces]);
+    bft_printf("      end  (idx = %10d)\n", idx[n_faces]);
   }
 
   else {
-    bft_printf(_("\nElements -> vertices connectivity:\n\n"));
+    bft_printf("\nElements -> vertices connectivity:\n\n");
     n_elements = this_section->n_elements;
     num = this_section->vertex_num;
     switch(this_section->stride) {
@@ -569,9 +612,9 @@ _fvm_nodal_section_dump(const fvm_nodal_section_t  *this_section)
 
   /* Numbers of associated elements in the parent mesh */
 
-  bft_printf(_("\nLocal element numbers in parent mesh:\n"));
+  bft_printf("\nLocal element numbers in parent mesh:\n");
   if (this_section->parent_element_num == NULL)
-    bft_printf(_("\n  Nil\n\n"));
+    bft_printf("\n  Nil\n\n");
   else {
     for (i = 0; i < this_section->n_elements; i++)
       bft_printf("  %10d %10d\n", i+1, this_section->parent_element_num[i]);
@@ -580,7 +623,7 @@ _fvm_nodal_section_dump(const fvm_nodal_section_t  *this_section)
   /* Global element numbers (only for parallel execution) */
 
   if (this_section->global_element_num != NULL) {
-    bft_printf(_("\nGlobal element numbers:\n"));
+    bft_printf("\nGlobal element numbers:\n");
     fvm_io_num_dump(this_section->global_element_num);
   }
 }
@@ -724,7 +767,7 @@ fvm_nodal_section_copy_on_write(fvm_nodal_section_t  *this_section,
 
   if (copy_face_index == true
       && this_section->face_index != NULL && this_section->_face_index == NULL) {
-    BFT_MALLOC(this_section->face_num, this_section->n_elements + 1, fvm_lnum_t);
+    BFT_MALLOC(this_section->_face_index, this_section->n_elements + 1, fvm_lnum_t);
     for (i = 0; i < (size_t)(this_section->n_elements + 1); i++) {
       this_section->_face_index[i] = this_section->face_index[i];
     }
@@ -734,7 +777,7 @@ fvm_nodal_section_copy_on_write(fvm_nodal_section_t  *this_section,
   if (copy_face_num == true
       && this_section->face_num != NULL && this_section->_face_num == NULL) {
     n_faces = this_section->face_index[this_section->n_elements];
-    BFT_MALLOC(this_section->face_num, n_faces, fvm_lnum_t);
+    BFT_MALLOC(this_section->_face_num, n_faces, fvm_lnum_t);
     for (i = 0; i < (size_t)n_faces; i++) {
       this_section->_face_num[i] = this_section->face_num[i];
     }
@@ -748,7 +791,7 @@ fvm_nodal_section_copy_on_write(fvm_nodal_section_t  *this_section,
       n_faces = this_section->n_faces;
     else
       n_faces = this_section->n_elements;
-    BFT_MALLOC(this_section->vertex_index, n_faces + 1, fvm_lnum_t);
+    BFT_MALLOC(this_section->_vertex_index, n_faces + 1, fvm_lnum_t);
     for (i = 0; i < (size_t)n_faces + 1; i++) {
       this_section->_vertex_index[i] = this_section->vertex_index[i];
     }
@@ -756,7 +799,7 @@ fvm_nodal_section_copy_on_write(fvm_nodal_section_t  *this_section,
   }
 
   if (copy_vertex_num == true && this_section->_vertex_num == NULL) {
-    BFT_MALLOC(this_section->vertex_num,
+    BFT_MALLOC(this_section->_vertex_num,
                this_section->connectivity_size, fvm_lnum_t);
     for (i = 0; i < this_section->connectivity_size; i++) {
       this_section->_vertex_num[i] = this_section->vertex_num[i];
@@ -1207,6 +1250,52 @@ fvm_nodal_change_parent_num(fvm_nodal_t       *this_nodal,
 
 }
 
+/*----------------------------------------------------------------------------
+ * Remove entity parent numbering; this is useful for example when we
+ * want to assign coordinates or fields to an extracted mesh using
+ * arrays relative to the mesh, and not to its parent.
+ *
+ * This is equivalent to calling fvm_nodal_change_parent_num(), with
+ * 'trivial' (1 o n) new_parent_num[] values.
+ *
+ * parameters:
+ *   this_nodal          <-- nodal mesh structure
+ *   entity_dim          <-- 3 for cells, 2 for faces, 1 for edges,
+ *                           and 0 for vertices
+ *----------------------------------------------------------------------------*/
+
+void
+fvm_nodal_remove_parent_num(fvm_nodal_t  *this_nodal,
+                            int           entity_dim)
+{
+  /* Vertices */
+
+  if (entity_dim == 0) {
+    this_nodal->parent_vertex_num = NULL;
+    if (this_nodal->_parent_vertex_num != NULL)
+      BFT_FREE(this_nodal->_parent_vertex_num);
+  }
+
+  /* Other elements */
+
+  else {
+
+    int  i = 0;
+    fvm_nodal_section_t  *section = NULL;
+
+    for (i = 0; i < this_nodal->n_sections; i++) {
+      section = this_nodal->sections[i];
+      if (section->entity_dim == entity_dim) {
+        section->parent_element_num = NULL;
+        if (section->_parent_element_num != NULL)
+          BFT_FREE(section->_parent_element_num);
+      }
+    }
+
+  }
+
+}
+
 /*----------------------------------------------------------------------------
  * Build external numbering for entities based on global numbers.
  *
@@ -1374,7 +1463,7 @@ fvm_nodal_transfer_vertices(fvm_nodal_t  *this_nodal,
 
     for (i = 0; i < this_nodal->n_vertices; i++) {
       for (j = 0; j < dim; j++)
-        _vertex_coords[j*dim + 1]
+        _vertex_coords[i*dim + j]
           = vertex_coords[(parent_vertex_num[i]-1)*dim + j];
     }
 
@@ -1686,6 +1775,301 @@ fvm_nodal_tesselate(fvm_nodal_t    *this_nodal,
   }
 }
 
+/*----------------------------------------------------------------------------
+ * Build a nodal representation structure based on extraction of a
+ * mesh's edges.
+ *
+ * parameters:
+ *   name        <-- name to assign to extracted mesh
+ *   this_nodal  <-> pointer to nodal mesh structure
+ *----------------------------------------------------------------------------*/
+
+fvm_nodal_t *
+fvm_nodal_copy_edges(const char         *name,
+                     const fvm_nodal_t  *this_nodal)
+{
+  int i;
+  fvm_lnum_t j, k;
+  fvm_lnum_t n_edges = 0, n_max_edges = 0;
+  fvm_nodal_t *new_nodal = NULL;
+  fvm_nodal_section_t *new_section = NULL;
+
+  BFT_MALLOC(new_nodal, 1, fvm_nodal_t);
+
+  /* Global indicators */
+
+  if (name != NULL) {
+    BFT_MALLOC(new_nodal->name, strlen(name) + 1, char);
+    strcpy(new_nodal->name, name);
+  }
+  else
+    new_nodal->name = NULL;
+
+  new_nodal->dim     = this_nodal->dim;
+  new_nodal->num_dom = this_nodal->num_dom;
+  new_nodal->n_doms  = this_nodal->n_doms;
+  new_nodal->n_sections = 1;
+
+  /* Local dimensions */
+
+  new_nodal->n_cells = 0;
+  new_nodal->n_faces = 0;
+  new_nodal->n_edges = 0;
+  new_nodal->n_vertices = this_nodal->n_vertices;
+
+  /* Local structures */
+
+  new_nodal->vertex_coords = this_nodal->vertex_coords;
+  new_nodal->_vertex_coords = NULL;
+
+  new_nodal->parent_vertex_num = this_nodal->parent_vertex_num;
+  new_nodal->_parent_vertex_num = NULL;
+
+  if (this_nodal->global_vertex_num != NULL) {
+    fvm_lnum_t n_ent
+      = fvm_io_num_get_local_count(this_nodal->global_vertex_num);
+    fvm_gnum_t global_count
+      = fvm_io_num_get_global_count(this_nodal->global_vertex_num);
+    const fvm_gnum_t *global_num
+      = fvm_io_num_get_global_num(this_nodal->global_vertex_num);
+
+    new_nodal->global_vertex_num
+      = fvm_io_num_create_shared(global_num, global_count, n_ent);
+  }
+  else
+    new_nodal->global_vertex_num = NULL;
+
+  /* Counting step */
+
+  for (i = 0; i < this_nodal->n_sections; i++) {
+    const fvm_nodal_section_t *this_section = this_nodal->sections[i];
+    if (this_section->vertex_index == NULL)
+      n_max_edges += (  fvm_nodal_n_edges_element[this_section->type]
+                      * this_section->n_elements);
+    else if (this_section->type == FVM_FACE_POLY)
+      n_max_edges += this_section->vertex_index[this_section->n_elements];
+    else if (this_section->type == FVM_CELL_POLY)
+      n_max_edges += this_section->vertex_index[this_section->n_faces];
+  }
+
+  BFT_MALLOC(new_nodal->sections, 1, fvm_nodal_section_t *);
+
+  new_section = fvm_nodal_section_create(FVM_EDGE);
+  new_nodal->sections[0] = new_section;
+
+  BFT_MALLOC(new_section->_vertex_num, n_max_edges*2, fvm_lnum_t);
+
+  /* Add edges */
+
+  for (i = 0; i < this_nodal->n_sections; i++) {
+
+    const fvm_nodal_section_t *this_section = this_nodal->sections[i];
+
+    if (   this_section->type == FVM_FACE_POLY
+        || this_section->type == FVM_CELL_POLY) {
+
+      fvm_lnum_t n_faces = this_section->type == FVM_FACE_POLY ?
+        this_section->n_elements : this_section->n_faces;
+
+      for (j = 0; j < n_faces; j++) {
+        const fvm_lnum_t face_start_id = this_section->vertex_index[j];
+        const fvm_lnum_t n_face_edges
+          = this_section->vertex_index[j+1] - this_section->vertex_index[j];
+        for (k = 0; k < n_face_edges; k++) {
+          new_section->_vertex_num[n_edges*2]
+            = this_section->vertex_num[face_start_id + k];
+          new_section->_vertex_num[n_edges*2 + 1]
+            = this_section->vertex_num[face_start_id + (k + 1)%n_face_edges];
+          n_edges += 1;
+        }
+      }
+
+    }
+    else {
+
+      fvm_lnum_t edges[2][12];
+
+      fvm_lnum_t n_elt_edges = fvm_nodal_n_edges_element[this_section->type];
+      fvm_lnum_t n_elts = this_section->n_elements;
+      fvm_lnum_t stride = this_section->stride;
+
+      switch (this_section->type) {
+
+      case FVM_EDGE:
+      case FVM_FACE_TRIA:
+      case FVM_FACE_QUAD:
+        for (j = 0; j < n_elt_edges; j++) {
+          edges[0][j] = j;
+          edges[1][j] = (j+1)%n_elt_edges;
+        }
+        break;
+
+      case FVM_CELL_TETRA:
+        edges[0][0] = 0; edges[1][0] = 1;
+        edges[0][1] = 1; edges[1][1] = 2;
+        edges[0][2] = 2; edges[1][2] = 0;
+        edges[0][3] = 0; edges[1][3] = 3;
+        edges[0][4] = 1; edges[1][4] = 3;
+        edges[0][5] = 2; edges[1][5] = 3;
+        break;
+
+      case FVM_CELL_PYRAM:
+        edges[0][0] = 0; edges[1][0] = 1;
+        edges[0][1] = 1; edges[1][1] = 2;
+        edges[0][2] = 2; edges[1][2] = 3;
+        edges[0][3] = 3; edges[1][3] = 0;
+        edges[0][4] = 0; edges[1][4] = 4;
+        edges[0][5] = 1; edges[1][5] = 4;
+        edges[0][6] = 2; edges[1][6] = 4;
+        edges[0][7] = 3; edges[1][7] = 4;
+        break;
+
+      case FVM_CELL_PRISM:
+        edges[0][0] = 0; edges[1][0] = 1;
+        edges[0][1] = 1; edges[1][1] = 2;
+        edges[0][2] = 2; edges[1][2] = 0;
+        edges[0][3] = 0; edges[1][3] = 3;
+        edges[0][4] = 1; edges[1][4] = 4;
+        edges[0][5] = 2; edges[1][5] = 5;
+        edges[0][6] = 3; edges[1][6] = 4;
+        edges[0][7] = 4; edges[1][7] = 5;
+        edges[0][8] = 5; edges[1][8] = 3;
+        break;
+
+      case FVM_CELL_HEXA:
+        edges[0][0] = 0; edges[1][0] = 1;
+        edges[0][1] = 1; edges[1][1] = 2;
+        edges[0][2] = 2; edges[1][2] = 3;
+        edges[0][3] = 3; edges[1][3] = 0;
+        edges[0][4] = 0; edges[1][4] = 4;
+        edges[0][5] = 1; edges[1][5] = 5;
+        edges[0][6] = 2; edges[1][6] = 6;
+        edges[0][7] = 3; edges[1][7] = 7;
+        edges[0][8] = 4; edges[1][8] = 5;
+        edges[0][9] = 5; edges[1][9] = 6;
+        edges[0][10] = 6; edges[1][10] = 7;
+        edges[0][11] = 7; edges[1][11] = 4;
+        break;
+
+      default:
+        assert(0);
+        edges[0][0] = -1; /* For nonempty default clause */
+      }
+
+      for (j = 0; j < n_elts; j++) {
+        const fvm_lnum_t *_vertex_num = this_section->vertex_num + (j*stride);
+        for (k = 0; k < n_elt_edges; k++) {
+          new_section->_vertex_num[n_edges*2] = _vertex_num[edges[0][k]];
+          new_section->_vertex_num[n_edges*2 + 1] = _vertex_num[edges[1][k]];
+          n_edges += 1;
+        }
+      }
+    }
+  } /* End of loop on sections */
+
+  assert(n_edges == n_max_edges);
+
+  /* Ensure edges are oriented in the same direction */
+
+  if (this_nodal->global_vertex_num != NULL) {
+
+    const fvm_gnum_t *v_num_g
+      = fvm_io_num_get_global_num(this_nodal->global_vertex_num);
+
+    for (j = 0; j < n_max_edges; j++) {
+      fvm_lnum_t vnum_1 = new_section->_vertex_num[j*2];
+      fvm_lnum_t vnum_2 = new_section->_vertex_num[j*2 + 1];
+      if (v_num_g[vnum_1 - 1] > v_num_g[vnum_2 - 1]) {
+        new_section->_vertex_num[j*2] = vnum_2;
+        new_section->_vertex_num[j*2 + 1] = vnum_1;
+      }
+
+    }
+
+  }
+  else {
+
+    for (j = 0; j < n_max_edges; j++) {
+      fvm_lnum_t vnum_1 = new_section->_vertex_num[j*2];
+      fvm_lnum_t vnum_2 = new_section->_vertex_num[j*2 + 1];
+      if (vnum_1 > vnum_2) {
+        new_section->_vertex_num[j*2] = vnum_2;
+        new_section->_vertex_num[j*2 + 1] = vnum_1;
+      }
+    }
+
+  }
+
+  /* Sort and remove duplicates
+     (use qsort rather than fvm_order_local_s() so as to sort in place) */
+
+  qsort(new_section->_vertex_num,
+        n_max_edges,
+        sizeof(fvm_lnum_t) * 2,
+        &_compare_edges);
+
+  {
+    fvm_lnum_t vn_1_p = -1;
+    fvm_lnum_t vn_2_p = -1;
+
+    n_edges = 0;
+
+    for (j = 0; j < n_max_edges; j++) {
+
+      fvm_lnum_t vn_1 = new_section->_vertex_num[j*2];
+      fvm_lnum_t vn_2 = new_section->_vertex_num[j*2 + 1];
+
+      if (vn_1 != vn_1_p || vn_2 != vn_2_p) {
+        new_section->_vertex_num[n_edges*2]     = vn_1;
+        new_section->_vertex_num[n_edges*2 + 1] = vn_2;
+        vn_1_p = vn_1;
+        vn_2_p = vn_2;
+        n_edges += 1;
+      }
+    }
+  }
+
+  /* Resize edge connectivity to adjust to final size */
+
+  BFT_REALLOC(new_section->_vertex_num, n_edges*2, fvm_lnum_t);
+  new_section->vertex_num = new_section->_vertex_num;
+
+  new_section->n_elements = n_edges;
+  new_nodal->n_edges = n_edges;
+
+  /* Build  global edge numbering if necessary */
+
+  if (new_nodal->n_doms > 1) {
+
+    fvm_gnum_t *edge_vertices_g; /* edges -> global vertices */
+
+    BFT_MALLOC(edge_vertices_g, n_edges*2, fvm_gnum_t);
+
+    if (this_nodal->global_vertex_num != NULL) {
+      const fvm_gnum_t *v_num_g
+        = fvm_io_num_get_global_num(this_nodal->global_vertex_num);
+      for (j = 0; j < n_edges; j++) {
+        edge_vertices_g[j*2]   = v_num_g[new_section->_vertex_num[j*2] - 1];
+        edge_vertices_g[j*2+1] = v_num_g[new_section->_vertex_num[j*2+1] - 1];
+      }
+    }
+    else {
+      for (j = 0; j < n_edges; j++) {
+        edge_vertices_g[j*2]     = new_section->_vertex_num[j*2];
+        edge_vertices_g[j*2 + 1] = new_section->_vertex_num[j*2 + 1];
+      }
+    }
+
+    new_section->global_element_num
+      = fvm_io_num_create_from_adj_s(NULL, edge_vertices_g, n_edges, 2);
+
+
+    BFT_FREE(edge_vertices_g);
+  };
+
+  return (new_nodal);
+}
+
 /*----------------------------------------------------------------------------
  * Dump printout of a nodal representation structure.
  *
@@ -1703,23 +2087,23 @@ fvm_nodal_dump(const fvm_nodal_t  *this_nodal)
   /* Global indicators */
   /*--------------------*/
 
-  bft_printf(_("\n"
-               "Mesh name:\"%s\"\n"),
+  bft_printf("\n"
+             "Mesh name:\"%s\"\n",
              this_nodal->name);
 
-  bft_printf(_("\n"
-               "Mesh dimension:               %d\n"
-               "Domain number:                %d\n"
-               "Number of domains:            %d\n"
-               "Number of sections:           %d\n"),
+  bft_printf("\n"
+             "Mesh dimension:               %d\n"
+             "Domain number:                %d\n"
+             "Number of domains:            %d\n"
+             "Number of sections:           %d\n",
              this_nodal->dim, this_nodal->num_dom, this_nodal->n_doms,
              this_nodal->n_sections);
 
-  bft_printf(_("\n"
-              "Number of cells:               %d\n"
-              "Number of faces:               %d\n"
-              "Number of edges:               %d\n"
-              "Number of vertices:            %d\n"),
+  bft_printf("\n"
+             "Number of cells:               %d\n"
+             "Number of faces:               %d\n"
+             "Number of edges:               %d\n"
+             "Number of vertices:            %d\n",
             this_nodal->n_cells,
             this_nodal->n_faces,
             this_nodal->n_edges,
@@ -1727,17 +2111,17 @@ fvm_nodal_dump(const fvm_nodal_t  *this_nodal)
 
   if (this_nodal->n_vertices > 0) {
 
-    bft_printf(_("\n"
-                 "Pointers to shareable arrays:\n"
-                 "  vertex_coords:        %p\n"
-                 "  parent_vertex_num:    %p\n"),
+    bft_printf("\n"
+               "Pointers to shareable arrays:\n"
+               "  vertex_coords:        %p\n"
+               "  parent_vertex_num:    %p\n",
                this_nodal->vertex_coords,
                this_nodal->parent_vertex_num);
 
-    bft_printf(_("\n"
-                 "Pointers to local arrays:\n"
-                 "  _vertex_coords:       %p\n"
-                 "  _parent_vertex_num:   %p\n"),
+    bft_printf("\n"
+               "Pointers to local arrays:\n"
+               "  _vertex_coords:       %p\n"
+               "  _parent_vertex_num:   %p\n",
                this_nodal->_vertex_coords,
                this_nodal->_parent_vertex_num);
 
@@ -1745,7 +2129,7 @@ fvm_nodal_dump(const fvm_nodal_t  *this_nodal)
 
     if (this_nodal->parent_vertex_num == NULL) {
 
-      bft_printf(_("\nVertex coordinates:\n\n"));
+      bft_printf("\nVertex coordinates:\n\n");
       switch(this_nodal->dim) {
       case 1:
         for (i = 0; i < this_nodal->n_vertices; i++)
@@ -1772,7 +2156,7 @@ fvm_nodal_dump(const fvm_nodal_t  *this_nodal)
     }
     else { /* if (this_nodal->parent_vertex_num != NULL) */
 
-      bft_printf(_("\nVertex parent and coordinates:\n\n"));
+      bft_printf("\nVertex parent and coordinates:\n\n");
 
       switch(this_nodal->dim) {
       case 1:
@@ -1811,7 +2195,7 @@ fvm_nodal_dump(const fvm_nodal_t  *this_nodal)
 
   /* Global vertex numbers (only for parallel execution) */
   if (this_nodal->global_vertex_num != NULL) {
-    bft_printf(_("\nGlobal vertex numbers:\n\n"));
+    bft_printf("\nGlobal vertex numbers:\n\n");
     fvm_io_num_dump(this_nodal->global_vertex_num);
   }
 
