@@ -117,13 +117,13 @@ typedef enum {
  *----------------------------------------------------------------------------*/
 
 inline static fvm_element_t
-_is_prism_or_poly(const fvm_lnum_t         cell_id,
-                  const int                n_face_lists,
-                  const fvm_lnum_t         face_list_shift[],
-                  const fvm_lnum_t  *const face_vertex_idx[],
-                  const fvm_lnum_t  *const face_vertex_num[],
-                  const fvm_lnum_t         cell_face_idx[],
-                  const fvm_lnum_t         cell_face_num[])
+_is_prism_or_poly(const fvm_lnum_t   cell_id,
+                  const int          n_face_lists,
+                  const fvm_lnum_t   face_list_shift[],
+                  const fvm_lnum_t  *face_vertex_idx[],
+                  const fvm_lnum_t  *face_vertex_num[],
+                  const fvm_lnum_t   cell_face_idx[],
+                  const fvm_lnum_t   cell_face_num[])
 {
   int         vtx_id_1, vtx_id_2;
   fvm_lnum_t  face_id, fl;
@@ -216,15 +216,15 @@ _is_prism_or_poly(const fvm_lnum_t         cell_id,
  *----------------------------------------------------------------------------*/
 
 inline static fvm_element_t
-_nodal_cell_from_desc(const fvm_lnum_t         cell_id,
-                      const int                n_face_lists,
-                      const fvm_lnum_t         face_list_shift[],
-                      const fvm_lnum_t  *const face_vertex_idx[],
-                      const fvm_lnum_t  *const face_vertex_num[],
-                      const fvm_lnum_t         cell_face_idx[],
-                      const fvm_lnum_t         cell_face_num[],
-                      fvm_lnum_t        *const cell_vtx_tria,
-                      fvm_lnum_t        *const cell_vtx_quad)
+_nodal_cell_from_desc(const fvm_lnum_t   cell_id,
+                      const int          n_face_lists,
+                      const fvm_lnum_t   face_list_shift[],
+                      const fvm_lnum_t  *face_vertex_idx[],
+                      const fvm_lnum_t  *face_vertex_num[],
+                      const fvm_lnum_t   cell_face_idx[],
+                      const fvm_lnum_t   cell_face_num[],
+                      fvm_lnum_t        *cell_vtx_tria,
+                      fvm_lnum_t        *cell_vtx_quad)
 {
   fvm_lnum_t  n_cell_faces;
   fvm_lnum_t  face_id, fl;
@@ -822,10 +822,10 @@ _nodal_from_desc_cnv_cel_hexa(const fvm_lnum_t  cell_vtx_quad[],
  *----------------------------------------------------------------------------*/
 
 inline static fvm_lnum_t
-_nodal_face_from_desc_size(const fvm_lnum_t         face_id,
-                           const int                n_face_lists,
-                           const fvm_lnum_t         face_list_shift[],
-                           const fvm_lnum_t  *const face_vertex_idx[])
+_nodal_face_from_desc_size(const fvm_lnum_t   face_id,
+                           const int          n_face_lists,
+                           const fvm_lnum_t   face_list_shift[],
+                           const fvm_lnum_t  *face_vertex_idx[])
 {
   fvm_lnum_t  fl, _face_id;
   fvm_lnum_t  n_face_vertices;
@@ -864,12 +864,12 @@ _nodal_face_from_desc_size(const fvm_lnum_t         face_id,
  *----------------------------------------------------------------------------*/
 
 inline static void
-_nodal_face_from_desc_copy(const fvm_lnum_t         face_id,
-                           const int                n_face_lists,
-                           const fvm_lnum_t         face_list_shift[],
-                           const fvm_lnum_t  *const face_vertex_idx[],
-                           const fvm_lnum_t  *const face_vertex_num[],
-                           fvm_lnum_t        *const face_vtx)
+_nodal_face_from_desc_copy(const fvm_lnum_t   face_id,
+                           const int          n_face_lists,
+                           const fvm_lnum_t   face_list_shift[],
+                           const fvm_lnum_t  *face_vertex_idx[],
+                           const fvm_lnum_t  *face_vertex_num[],
+                           fvm_lnum_t        *face_vtx)
 {
   fvm_lnum_t  fl, _face_id;
   fvm_lnum_t  vtx, vertex_id, vertex_id_start, vertex_id_end;
@@ -909,16 +909,16 @@ _nodal_face_from_desc_copy(const fvm_lnum_t         face_id,
  *----------------------------------------------------------------------------*/
 
 static void
-_fvm_nodal_extract_polyhedra(fvm_nodal_section_t  *const this_section,
-                             const fvm_lnum_t            n_polys,
-                             const fvm_lnum_t            list_poly[],
-                             const int                   n_face_lists,
-                             const fvm_lnum_t            face_list_shift[],
-                             const fvm_lnum_t     *const face_vertex_idx[],
-                             const fvm_lnum_t     *const face_vertex_num[],
-                             const fvm_lnum_t            cell_face_idx[],
-                             const fvm_lnum_t            cell_face_num[],
-                             fvm_lnum_t           *      cell_face_list[])
+_fvm_nodal_extract_polyhedra(fvm_nodal_section_t  *this_section,
+                             const fvm_lnum_t      n_polys,
+                             const fvm_lnum_t      list_poly[],
+                             const int             n_face_lists,
+                             const fvm_lnum_t      face_list_shift[],
+                             const fvm_lnum_t     *face_vertex_idx[],
+                             const fvm_lnum_t     *face_vertex_num[],
+                             const fvm_lnum_t      cell_face_idx[],
+                             const fvm_lnum_t      cell_face_num[],
+                             fvm_lnum_t           *cell_face_list[])
 {
   fvm_lnum_t   n_faces, n_cell_faces;
   fvm_lnum_t   c_cell_face_vertex_idxs, c_cell_face_vertex_nums;
@@ -1119,9 +1119,9 @@ _fvm_nodal_extract_polyhedra(fvm_nodal_section_t  *const this_section,
  *----------------------------------------------------------------------------*/
 
 static void
-_raise_sections_parent_num(const int                   n_sections,
-                           fvm_nodal_section_t  *const sections[],
-                           const fvm_lnum_t            parent_element_num[])
+_raise_sections_parent_num(const int             n_sections,
+                           fvm_nodal_section_t  *sections[],
+                           const fvm_lnum_t      parent_element_num[])
 {
   int  section_id;
   fvm_lnum_t  element_counter;
@@ -1165,8 +1165,8 @@ _raise_sections_parent_num(const int                   n_sections,
  *----------------------------------------------------------------------------*/
 
 static void
-_optimize_sections_parent_num(const int                   n_sections,
-                              fvm_nodal_section_t  *const sections[])
+_optimize_sections_parent_num(const int             n_sections,
+                              fvm_nodal_section_t  *sections[])
 {
   int  section_id;
   fvm_lnum_t  element_counter;
@@ -1211,9 +1211,9 @@ _optimize_sections_parent_num(const int                   n_sections,
  *----------------------------------------------------------------------------*/
 
 static void
-_fvm_nodal_add_sections(fvm_nodal_t          *const this_nodal,
-                        const int                   n_sections,
-                        fvm_nodal_section_t  *const sections[])
+_fvm_nodal_add_sections(fvm_nodal_t          *this_nodal,
+                        const int             n_sections,
+                        fvm_nodal_section_t  *sections[])
 {
   int  section_id, section_count;
 
@@ -1279,17 +1279,17 @@ _fvm_nodal_add_sections(fvm_nodal_t          *const this_nodal,
  *----------------------------------------------------------------------------*/
 
 void
-fvm_nodal_from_desc_add_cells(fvm_nodal_t        *const this_nodal,
-                              const fvm_lnum_t          n_extr_cells,
-                              const fvm_lnum_t          extr_cells[],
-                              const int                 n_face_lists,
-                              const fvm_lnum_t          face_list_shift[],
-                              const fvm_lnum_t   *const face_vertex_idx[],
-                              const fvm_lnum_t   *const face_vertex_num[],
-                              const fvm_lnum_t          cell_face_idx[],
-                              const fvm_lnum_t          cell_face_num[],
-                              const fvm_lnum_t          parent_cell_num[],
-                              fvm_lnum_t         *      cell_face_list[])
+fvm_nodal_from_desc_add_cells(fvm_nodal_t        *this_nodal,
+                              const fvm_lnum_t    n_extr_cells,
+                              const fvm_lnum_t    extr_cells[],
+                              const int           n_face_lists,
+                              const fvm_lnum_t    face_list_shift[],
+                              const fvm_lnum_t   *face_vertex_idx[],
+                              const fvm_lnum_t   *face_vertex_num[],
+                              const fvm_lnum_t    cell_face_idx[],
+                              const fvm_lnum_t    cell_face_num[],
+                              const fvm_lnum_t    parent_cell_num[],
+                              fvm_lnum_t         *cell_face_list[])
 {
   int  type_id;
   fvm_lnum_t  cell_counter, cell_id;
@@ -1469,8 +1469,8 @@ fvm_nodal_from_desc_add_cells(fvm_nodal_t        *const this_nodal,
   fvm_parall_counter(&n_orient_pbs, 1);
 
   if (n_orient_pbs > 0)
-    bft_printf(_("Warning: Possible nodal connectivity orientation\n"
-                 "         problems for at least %d cells\n"),
+    bft_printf("Warning: Possible nodal connectivity orientation\n"
+               "         problems for at least %d cells\n",
                n_orient_pbs);
 
   /* Extraction of remaining polyhedra */
@@ -1531,14 +1531,14 @@ fvm_nodal_from_desc_add_cells(fvm_nodal_t        *const this_nodal,
  *----------------------------------------------------------------------------*/
 
 void
-fvm_nodal_from_desc_add_faces(fvm_nodal_t        *const this_nodal,
-                              const fvm_lnum_t          n_extr_faces,
-                              const fvm_lnum_t          extr_faces[],
-                              const int                 n_face_lists,
-                              const fvm_lnum_t          face_list_shift[],
-                              const fvm_lnum_t   *const face_vertex_idx[],
-                              const fvm_lnum_t   *const face_vertex_num[],
-                              const fvm_lnum_t          parent_face_num[])
+fvm_nodal_from_desc_add_faces(fvm_nodal_t        *this_nodal,
+                              const fvm_lnum_t    n_extr_faces,
+                              const fvm_lnum_t    extr_faces[],
+                              const int           n_face_lists,
+                              const fvm_lnum_t    face_list_shift[],
+                              const fvm_lnum_t   *face_vertex_idx[],
+                              const fvm_lnum_t   *face_vertex_num[],
+                              const fvm_lnum_t    parent_face_num[])
 {
   int  type_id;
   fvm_lnum_t  face_counter, face_id;
