@@ -151,6 +151,32 @@ fvm_order_local_s(const fvm_lnum_t  list[],
                   size_t            stride,
                   size_t            nb_ent);
 
+/*----------------------------------------------------------------------------
+ * Return a lexicographical ordering table associated with an indexed array
+ * of global numbers.
+ *
+ * parameters:
+ *   list     <-- optional list (1 to n numbering) of selected entities
+ *                (or NULL if all nb_ent are selected). This list may
+ *                contain element numbers in any order
+ *   number   <-- array of all entity numbers (numbers of entity i start
+ *                at index[i] or _index[i] (reduced index) if list exists).
+ *                If list = NULL, a default 1 to n numbering is considered)
+ *   index    <-- number of values to compare for each entity
+ *   nb_ent   <-- number of entities considered
+ *
+ * returns:
+ *   pointer to list of nb_ent entities (0 to n-1 numbering) ordered by
+ *   increasing associated number. The calling code is responsible for
+ *   freeing this array when it is not needed anymore.
+ *----------------------------------------------------------------------------*/
+
+fvm_lnum_t *
+fvm_order_local_i(const fvm_lnum_t  list[],
+                  const fvm_gnum_t  number[],
+                  const fvm_lnum_t  index[],
+                  size_t            nb_ent);
+
 /*----------------------------------------------------------------------------
  * Compute an ordering table associated with an array of global numbers.
  *
@@ -195,6 +221,29 @@ fvm_order_local_allocated_s(const fvm_lnum_t  list[],
                             fvm_lnum_t        order[],
                             const size_t      nb_ent);
 
+/*----------------------------------------------------------------------------
+ * Compute a lexicographical ordering table associated with an indexed array
+ * of global numbers.
+ *
+ * parameters:
+ *   list     <-- optional list (1 to n numbering) of selected entities
+ *                (or NULL if all nb_ent are selected). This list may
+ *                contain element numbers in any order
+ *   number   <-- array of all entity numbers (numbers of entity i start
+ *                at index[i] or _index[i] (reduced index) if list exists).
+ *                If list = NULL, a default 1 to n numbering is considered)
+ *   index    <-- number of values to compare for each entity (from 0)
+ *   order    --> pointer to pre-allocated ordering table
+ *   nb_ent   <-- number of entities considered
+ *----------------------------------------------------------------------------*/
+
+void
+fvm_order_local_allocated_i(const fvm_lnum_t  list[],
+                            const fvm_gnum_t  number[],
+                            const fvm_lnum_t  index[],
+                            fvm_lnum_t        order[],
+                            const size_t      nb_ent);
+
 /*----------------------------------------------------------------------------
  * Build local renumbering array based on ordering of entities.
  *
