@@ -61,12 +61,27 @@ extern "C" {
 
 #define FVM_MPI_TAG      (int)('F'+'V'+'M') /* MPI tag for FVM operations */
 
-#define FVM_MPI_LNUM     MPI_INT            /* MPI type corresponding to
-                                               fvm_lnum_t integer type */
-#define FVM_MPI_GNUM     MPI_UNSIGNED       /* MPI type corresponding to
-                                               fvm_gnum_t integer type */
-#define FVM_MPI_COORD    MPI_DOUBLE         /* MPI type corresponding to
-                                               fvm_coord_t integer type */
+/* MPI type for fvm_gnum_t integer type (depends on configuration) */
+
+#if defined(FVM_HAVE_LONG_GNUM)
+  #if (FVM_SIZEOF_LONG == 8)
+    #define FVM_MPI_GNUM     MPI_UNSIGNED_LONG
+  #elif (FVM_SIZEOF_LONG_LONG == 8)
+    #if defined(MPI_UNSIGNED_LONG_LONG)
+      #define FVM_MPI_GNUM     MPI_UNSIGNED_LONG_LONG
+    #elif defined(MPI_LONG_LONG)
+      #define FVM_MPI_GNUM     MPI_LONG_LONG
+    #endif
+  #endif
+  #if !defined(FVM_MPI_GNUM)
+    #error
+  #endif
+#else
+  #define FVM_MPI_GNUM       MPI_UNSIGNED
+#endif
+
+#define FVM_MPI_LNUM     MPI_INT         /* MPI type for fvm_lnum_t type */
+#define FVM_MPI_COORD    MPI_DOUBLE      /* MPI type for fvm_coord_t type */
 
 #endif
 
