@@ -520,6 +520,7 @@ _copy_array_gather(fvm_part_to_block_t   *d,
  * arguments:
  *   rank_id        <-- id of local rank
  *   n_ranks        <-- number of associated ranks
+ *   min_rank_step  <-- minimum rank step between blocks
  *   min_block_size <-- minimum number of entities per block
  *   n_g_ents       <-- total number of associated entities
  *
@@ -530,6 +531,7 @@ _copy_array_gather(fvm_part_to_block_t   *d,
 fvm_part_to_block_info_t
 fvm_part_to_block_compute_sizes(int         rank_id,
                                 int         n_ranks,
+                                int         min_rank_step,
                                 fvm_lnum_t  min_block_size,
                                 fvm_gnum_t  n_g_ents)
 {
@@ -537,6 +539,7 @@ fvm_part_to_block_compute_sizes(int         rank_id,
 
   fvm_block_dist_info_t _bi= fvm_block_dist_compute_sizes(rank_id,
                                                           n_ranks,
+                                                          min_rank_step,
                                                           min_block_size,
                                                           n_g_ents);
 
