@@ -498,13 +498,13 @@ _transform_dump(_transform_t  *this_transform,
 {
   _transform_t  *tr = this_transform;
 
-  bft_printf(_("\n"
-               "  Transform:           %d\n"
-               "  Type:                %s\n"
-               "  External_num         %d\n"
-               "  Reverse id           %d\n"
-               "  Parent ids           %d %d\n"
-               "  First equivalent id  %d\n"),
+  bft_printf("\n"
+             "  Transform:           %d\n"
+             "  Type:                %s\n"
+             "  External_num         %d\n"
+             "  Reverse id           %d\n"
+             "  Parent ids           %d %d\n"
+             "  First equivalent id  %d\n",
              id,
              fvm_periodicity_type_name[tr->type],
              tr->external_num,
@@ -512,9 +512,9 @@ _transform_dump(_transform_t  *this_transform,
              tr->parent_ids[0], tr->parent_ids[1],
              tr->equiv_id);
 
-  bft_printf(_("  Matrix:              %12.5g %12.5g %12.5g %12.5g\n"
-               "                       %12.5g %12.5g %12.5g %12.5g\n"
-               "                       %12.5g %12.5g %12.5g %12.5g\n"),
+  bft_printf("  Matrix:              %12.5g %12.5g %12.5g %12.5g\n"
+             "                       %12.5g %12.5g %12.5g %12.5g\n"
+             "                       %12.5g %12.5g %12.5g %12.5g\n",
              tr->m[0][0], tr->m[0][1], tr->m[0][2], tr->m[0][3],
              tr->m[1][0], tr->m[1][1], tr->m[1][2], tr->m[1][3],
              tr->m[2][0], tr->m[2][1], tr->m[2][2], tr->m[2][3]);
@@ -1344,18 +1344,18 @@ fvm_periodicity_dump(const fvm_periodicity_t  *this_periodicity)
   int  i;
   int  level = 0;
 
-  bft_printf(_("\n"
-               "Periodicity:          %p\n"), this_periodicity);
+  bft_printf("\n"
+             "Periodicity:          %p\n", this_periodicity);
 
   if (this_periodicity == NULL) {
     bft_printf("\n");
     return;
   }
 
-  bft_printf(_("Number of transforms  %d\n"
-               "Number of levels  %d\n"
-               "Levels index      %d %d %d %d\n"
-               "Equivalence tolerance %12.5g\n"),
+  bft_printf("Number of transforms  %d\n"
+             "Number of levels  %d\n"
+             "Levels index      %d %d %d %d\n"
+             "Equivalence tolerance %12.5g\n",
              this_periodicity->n_transforms,
              this_periodicity->n_levels,
              this_periodicity->tr_level_idx[0],
@@ -1367,7 +1367,7 @@ fvm_periodicity_dump(const fvm_periodicity_t  *this_periodicity)
   for (i = 0; i < this_periodicity->n_transforms; i++) {
 
     if (i == this_periodicity->tr_level_idx[level]) {
-      bft_printf(_("\n  Combination level %d\n"), level);
+      bft_printf("\n  Combination level %d\n", level);
       level += 1;
     }
 
