@@ -761,7 +761,7 @@ fvm_selector_create(int                           dim,
   _assign_groups(selector, group_class_set);
   _assign_attributes(selector, group_class_set);
 
-  if (group_class_id != NULL) {
+  if (group_class_id != NULL && n_group_classes > 0) {
 
     BFT_MALLOC(selector->_n_group_class_elements, n_group_classes, fvm_lnum_t);
     BFT_MALLOC(selector->_group_class_elements, n_group_classes, fvm_lnum_t *);
@@ -1060,68 +1060,68 @@ fvm_selector_dump(const fvm_selector_t  *this_selector)
   const fvm_selector_t  *ts = this_selector;
 
   if (ts == NULL) {
-    bft_printf(_("\n"
-                 "Null selector dump:\n"));
+    bft_printf("\n"
+               "Null selector dump:\n");
     return;
   }
 
-  bft_printf(_("\n"
-               "Selector dump:\n"
-               "  Dimension:                          %d\n"
-               "  Number of selectable elements:      %d\n"
-               "  Shared group class id's:            %p\n"
-               "  Private group class id's:           %p\n"
-               "  Group class id base:                %d\n"
-               "  Number of associated group classes: %d\n"
-               "  Number of associated groups:        %d\n"
-               "  Number of associated attributes:    %d\n"),
+  bft_printf("\n"
+             "Selector dump:\n"
+             "  Dimension:                          %d\n"
+             "  Number of selectable elements:      %d\n"
+             "  Shared group class id's:            %p\n"
+             "  Private group class id's:           %p\n"
+             "  Group class id base:                %d\n"
+             "  Number of associated group classes: %d\n"
+             "  Number of associated groups:        %d\n"
+             "  Number of associated attributes:    %d\n",
              ts->dim, (int)ts->n_elements,
              ts->group_class_id, ts->_group_class_id,
              ts->group_class_id_base,
              ts->n_group_classes, ts->n_groups, ts->n_attributes);
 
   if (ts->n_groups > 0) {
-    bft_printf(_("  Group names:\n"));
+    bft_printf("  Group names:\n");
     for (i = 0; i < ts->n_groups; i++)
-      bft_printf(_("    \"%s\"\n"), ts->group_name[i]);
+      bft_printf("    \"%s\"\n", ts->group_name[i]);
   }
   if (ts->n_attributes > 0) {
-    bft_printf(_("  Attributes:\n"));
+    bft_printf("  Attributes:\n");
     for (i = 0; i < ts->n_attributes; i++)
-      bft_printf(_("    %d\n"), ts->attribute[i]);
+      bft_printf("    %d\n", ts->attribute[i]);
   }
 
   if (ts->n_group_classes > 0) {
-    bft_printf(_("  Group classes:\n"));
+    bft_printf("  Group classes:\n");
     for (i = 0; i < ts->n_group_classes; i++) {
-      bft_printf(_("    Group class %d\n"), (int)i);
+      bft_printf("    Group class %d\n", (int)i);
       if (ts->n_groups > 0) {
-        bft_printf(_("      Number of groups: %d\n"),
+        bft_printf("      Number of groups: %d\n",
                    ts->n_class_groups[i]);
         for (j = 0; j < ts->n_class_groups[i]; j++)
-          bft_printf(_("        %d\n"), ts->group_ids[i][j]);
+          bft_printf("        %d\n", ts->group_ids[i][j]);
       }
       if (ts->n_attributes > 0) {
-        bft_printf(_("      Number of attributes: %d\n"),
+        bft_printf("      Number of attributes: %d\n",
                    ts->n_class_attributes[i]);
         for (j = 0; j < ts->n_class_attributes[i]; j++)
-          bft_printf(_("        %d\n"), ts->attribute_ids[i][j]);
+          bft_printf("        %d\n", ts->attribute_ids[i][j]);
       }
     }
   }
 
-  bft_printf(_("  Shared coordinates:                 %p\n"
-               "  Private coordinates:                %p\n"
-               "  Shared normals;                     %p\n"
-               "  Private normals:                    %p\n"
-               "  Operations list:                    %p\n"),
+  bft_printf("  Shared coordinates:                 %p\n"
+             "  Private coordinates:                %p\n"
+             "  Shared normals;                     %p\n"
+             "  Private normals:                    %p\n"
+             "  Operations list:                    %p\n",
              ts->coords, ts->_coords, ts->normals, ts->_normals,
              ts->_operations);
 
   if (ts->n_group_classes > 0) {
-    bft_printf(_("  Number of elements per group class:\n"));
+    bft_printf("  Number of elements per group class:\n");
     for (i = 0; i < ts->n_group_classes; i++) {
-      bft_printf(_("    %d (%p)\n"),
+      bft_printf("    %d (%p)\n",
                  (int)ts->_n_group_class_elements[i],
                  ts->_group_class_elements[i]);
     }
