@@ -512,10 +512,10 @@ _parser_dump(const _parser_t  *this_parser)
   /* Global indicators */
   /*-------------------*/
 
-  bft_printf(_("\n"
-               "Parser:\n\n"
-               "Number of operators:  %d\n"
-               "Number of keywords:   %d\n\n"),
+  bft_printf("\n"
+             "Parser:\n\n"
+             "Number of operators:  %d\n"
+             "Number of keywords:   %d\n\n",
              this_parser->n_operators,
              this_parser->n_keywords);
 
@@ -523,24 +523,24 @@ _parser_dump(const _parser_t  *this_parser)
   /* Operators and related part of keywords array */
 
   if (this_parser->n_operators > 0)
-    bft_printf(_("Operators:\n"
+    bft_printf("Operators:\n"
                "    id  | name     | code | pri | type  \n"
-               "    ------------------------------------\n"));
+               "    ------------------------------------\n");
 
   for (i = 0; i < this_parser->n_operators; i++) {
     const _operator_t *op = this_parser->operators + i;
-    bft_printf(_("   %4d | %8s | %4d | %3d | %s\n"),
+    bft_printf("   %4d | %8s | %4d | %3d | %s\n",
                i, op->name, op->code, op->priority, type_name[op->type]);
   }
 
   if (this_parser->n_keywords > 0)
-    bft_printf(_("\n"
-                 "Keywords:\n"
+    bft_printf("\n"
+               "Keywords:\n"
                "    id  | op_id | name\n"
-                 "    ------------------\n"));
+               "    ------------------\n");
 
   for (i = 0; i < this_parser->n_keywords; i++)
-    bft_printf(_("   %4d | %5d | %s\n"),
+    bft_printf("   %4d | %5d | %s\n",
                i, this_parser->keyword_op_id[i], this_parser->keyword[i]);
 
   bft_printf("\n");
@@ -808,19 +808,19 @@ _dump_tokenized(const char          *infix,
 {
   int i;
 
-  bft_printf(_("\n"
-               "Tokenization:\n\n"
-               "Infix:\n%s\n"
-               "Tokens: %d\n"),
+  bft_printf("\n"
+             "Tokenization:\n\n"
+             "Infix:\n%s\n"
+             "Tokens: %d\n",
              infix, te.n_tokens);
 
   for (i = 0; i < te.n_tokens; i++) {
-    bft_printf(_("  %3d: %-20s"), i, te.tokens + te.token_id[i]);
-    bft_printf(_(" (%d bytes from infix start"), te.infix_id[i]);
+    bft_printf("  %3d: %-20s", i, te.tokens + te.token_id[i]);
+    bft_printf(" (%d bytes from infix start", te.infix_id[i]);
     if (te.protected[i] != 0)
-      bft_printf(_(", protected)\n"));
+      bft_printf(", protected)\n");
     else
-      bft_printf(_(")\n"));
+      bft_printf(")\n");
   }
 }
 
@@ -3178,13 +3178,13 @@ fvm_selector_postfix_dump(const fvm_selector_postfix_t  *pf,
 {
   size_t i = 0;
 
-  bft_printf(_("\n"
-               "Postfix expression dump:\n"
-               "  Coordinates dependency:   %d\n"
-               "  Normals dependency:       %d\n"
-               "  Infix:\n"
-               "    %s\n"
-               "  Elements:\n"),
+  bft_printf("\n"
+             "Postfix expression dump:\n"
+             "  Coordinates dependency:   %d\n"
+             "  Normals dependency:       %d\n"
+             "  Infix:\n"
+             "    %s\n"
+             "  Elements:\n",
              (int)pf->coords_dependency,
              (int)pf->normals_dependency,
              pf->infix);
@@ -3248,7 +3248,7 @@ fvm_selector_postfix_dump(const fvm_selector_postfix_t  *pf,
   }
 
   if (pf->n_missing_operands > 0) {
-    bft_printf(_("  Missing operands:         %d\n"),
+    bft_printf("  Missing operands:         %d\n",
                pf->n_missing_operands);
     for (i = 0; i < (size_t)(pf->n_missing_operands); i++)
       bft_printf("    %s\n", pf->missing_operand[i]);
