@@ -930,6 +930,23 @@ fvm_triangulate_polygon(int                             dim,
 
   /* Initialize state structure */
 
+  if (n_vertices > state->n_vertices_max) {
+
+    int n_vertices_max = n_vertices*2;
+    int n_edges_max = (2*n_vertices_max) - 3;
+    int n_edges_tot_max = n_edges_max * (n_edges_max - 1) / 2;
+
+    state->n_vertices_max = n_vertices_max;
+    BFT_REALLOC(state->triangle_vertices, (n_vertices_max - 2) * 3, int);
+    BFT_REALLOC(state->coords, n_vertices_max*3, fvm_coord_t);
+    BFT_REALLOC(state->list_previous, n_vertices_max, int);
+    BFT_REALLOC(state->list_next, n_vertices_max, int);
+    BFT_REALLOC(state->edge_vertices, n_edges_tot_max*2, int);
+    BFT_REALLOC(state->edge_neighbors, n_edges_tot_max*2, int);
+    BFT_REALLOC(state->edge_is_delaunay, n_edges_tot_max, _Bool);
+    BFT_REALLOC(state->concave, n_vertices_max, _Bool);
+  }
+
   if (parent_vertex_num != NULL) {
     if (polygon_vertices != NULL) {
       for (i = 0; i < n_vertices; i++) {
